/*
 ****************************************************************************************
 * DISCLAIMER
 ****************************************************************************************
 * This software and/or information (the "Material") is supplied by Renesas Electronics
 * Corporation. and is only intended for use with Renesas products. No other uses are authorized.
 * The Material is owned by Renesas Electronics Corporation and is protected under all applicable laws,
 * including copyright laws.
 * THIS MATERIAL IS PROVIDED "AS IS," AND RENESAS MAKES NO WARRANTIES REGARDING THIS MATERIAL,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
 * TO THE MAXIMUM EXTENT PERMITTED BY LAW, NEITHER RENESAS ELECTRONICS CORP. NOR ANY OF ITS
 * AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS MATERIAL, EVEN IF RENESAS OR ITS AFFILIATES
 * HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this Material
 * and to discontinue its availability
 *
 ****************************************************************************************
*/
#include "ble_host_thread.h"
#include "rble_host.h"
#include "config.h"

void ble_host_thread_entry(void);

/* BLE Host Thread entry function */
void ble_host_thread_entry(void)
{
    uint32_t events;

    // Open IRQ channel
    g_ble_ready_irq.p_api->open(g_ble_ready_irq.p_ctrl, g_ble_ready_irq.p_cfg);

    /*
     * Reset the RL78G1D
     *
     */
    g_ioport_on_ioport.pinWrite(TOOL0, IOPORT_LEVEL_HIGH);
    g_ioport_on_ioport.pinWrite(RL78_RESET, IOPORT_LEVEL_LOW);
    R_BSP_SoftwareDelay(10,BSP_DELAY_UNITS_MILLISECONDS);
    g_ioport_on_ioport.pinWrite(RL78_RESET, IOPORT_LEVEL_HIGH);

    // Wait for BLE ready event
    tx_event_flags_get(&g_ble_ready_event, 0x01, TX_OR, &events, TX_WAIT_FOREVER);

    /* This thread process the events and commands from UART */
    while (1)
    {
        rBLE_Run();
        // Thread Object should be used to synchronize this thread
        tx_thread_sleep (1);
    }
}

/*
 * Accelerometer Interrupt Handler
 */
void ble_ready_irq_callback(external_irq_callback_args_t *p_args)
{
    (void) ((p_args));
    // BLE radio is ready; notify others about the event
    tx_event_flags_set(&g_ble_ready_event, 0x01, TX_OR);
}

