/*
 ****************************************************************************************
 * DISCLAIMER
 ****************************************************************************************
 * This software and/or information (the "Material") is supplied by Renesas Electronics
 * Corporation. and is only intended for use with Renesas products. No other uses are authorized.
 * The Material is owned by Renesas Electronics Corporation and is protected under all applicable laws,
 * including copyright laws.
 * THIS MATERIAL IS PROVIDED "AS IS," AND RENESAS MAKES NO WARRANTIES REGARDING THIS MATERIAL,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
 * TO THE MAXIMUM EXTENT PERMITTED BY LAW, NEITHER RENESAS ELECTRONICS CORP. NOR ANY OF ITS
 * AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS MATERIAL, EVEN IF RENESAS OR ITS AFFILIATES
 * HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this Material
 * and to discontinue its availability
 *
 ****************************************************************************************
 * common.h
 *
 *  Created on: Jun 14, 2016
 *      Author: Lokesh.Vasantha
 ****************************************************************************************
 */

#ifndef COMMON_H_
#define COMMON_H_

#include "hal_data.h"
#include "tx_api.h"
#include "db_handle.h"

#define USER_DEBUG 0
#define USER_DEBUG_ON_LCD 0

#define ACTIVITY_VAL SCS_HDL_SERVICE1_SV1_CHAR1_NTF_VAL
#define HEALTHCARE_VAL SCS_HDL_SERVICE1_SV1_CHAR2_NTF_VAL

typedef struct
{
    uint16_t x;
    uint16_t y;
    uint16_t z;
}xyz_t;

// data structure to house all available sensor data for BLE Solution Kit
typedef struct activity_data_t
{
    uint16_t light;
    uint16_t pressure;
    uint16_t temperature;
    uint16_t humidity;
    uint16_t distance;
    uint16_t calories;
    uint16_t steps;
} activity_data;

typedef enum {
    PUSH_BUTTON,
    TEMPERATURE,
    ACCELEROMETER,
    POTENTIOMETER,
    TOUCH_SENSOR,
}SENSOR_TYPE;

typedef struct
{
    SENSOR_TYPE hdr_val;
} msg_hdr_t;

typedef struct
{   msg_hdr_t msg_hdr;
    uint8_t pb_switch_num;
    uint8_t level;
} pb_switch_payload_t;

typedef struct
{   
    msg_hdr_t msg_hdr;
    uint32_t temp;
} temperature_payload_t;

typedef struct
{
    msg_hdr_t msg_hdr;
    xyz_t  xyz;
}accelerometer_payload_t;

typedef struct
{
    msg_hdr_t msg_hdr;
    uint16_t  touch;
}touch_sensor_payload_t;


#endif /* COMMON_H_ */

