/**
 ****************************************************************************************
 * DISCLAIMER
 ****************************************************************************************
 * This software and/or information (the "Material") is supplied by Renesas Electronics
 * Corporation. and is only intended for use with Renesas products. No other uses are authorized.
 * The Material is owned by Renesas Electronics Corporation and is protected under all applicable laws,
 * including copyright laws.
 * THIS MATERIAL IS PROVIDED "AS IS," AND RENESAS MAKES NO WARRANTIES REGARDING THIS MATERIAL,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
 * TO THE MAXIMUM EXTENT PERMITTED BY LAW, NEITHER RENESAS ELECTRONICS CORP. NOR ANY OF ITS
 * AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS MATERIAL, EVEN IF RENESAS OR ITS AFFILIATES
 * HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this Material
 * and to discontinue its availability
 *
 ****************************************************************************************
 *
 * @file		rscip.h
 *
 * @brief	RSCIP module header file.
 *
 * Copyright(C) 2013-2014 Renesas Electronics Corporation
 *
 * $Rev: 2144 $
 *
 ****************************************************************************************
 */

#ifndef RSCIP_H_
#define RSCIP_H_


/*
 * INCLUDE FILES
 ****************************************************************************************
 */

#include "rscip_ext.h"
#include "stdbool.h"

/*
 * DEFINES
 ****************************************************************************************
 */


/*
 * MACROS
 ****************************************************************************************
 */


/*
 * TYPE DEFINITIONS
 ****************************************************************************************
 */

typedef enum {
	RSCIP_OK,
	RSCIP_NOT_ACTIVE,
	RSCIP_INVALID_PARAMTER,
	RSCIP_BUSY,
	RSCIP_ERROR,
	RSCIP_CONFIG_ERROR,
	RSCIP_SYNC_TX_ERROR,
	RSCIP_CONFIG_TX_ERROR,
	RSCIP_PACKET_TX_ERROR,
} RSCIP_RESULT_CODE;

typedef enum {
	RSCIP_HCI_COMMAND			= 1,
	RSCIP_HCI_ACL_DATA			= 2,
	RSCIP_HCI_SYNCHRONOUS_DATA	= 3,
	RSCIP_HCI_EVENT				= 4,
	RSCIP_RBLE_COMMAND			= 5,
	RSCIP_RBLE_EVENT			= 6,
	RSCIP_VENDER_SPECIFIC		= 14,
} RSCIP_PACKET_TYPE;


typedef void (*RSCIP_Active_Callback)(void);
typedef void (*RSCIP_Write_Callback)(
									 uint8_t			*bufptr
									);
typedef	bool (*RSCIP_Read_Callback)(
									RSCIP_PACKET_TYPE	type,
									uint8_t				*bufptr,
									uint16_t			size
									);
typedef	void (*RSCIP_Reset_Callback)(void);
typedef void (*RSCIP_Error_Callback)(
									 RSCIP_RESULT_CODE	error
									);


typedef struct {
	RSCIP_Active_Callback	active_callback;
	RSCIP_Read_Callback		read_callback;
	RSCIP_Write_Callback	write_callback;
	RSCIP_Reset_Callback	reset_callback;
	RSCIP_Error_Callback	error_callback;
} RSCIP_Callback_t;


/*
 * GLOBAL VARIABLE DECLARATIONS
 ****************************************************************************************
 */


/*
 * FUNCTION DECLARATIONS
 ****************************************************************************************
 */

#ifdef __cplusplus
extern "C" {
#endif
RSCIP_RESULT_CODE RSCIP_Initialize(RSCIP_Callback_t *callback);
RSCIP_RESULT_CODE RSCIP_Write(
							  RSCIP_PACKET_TYPE		type,
							  uint8_t				*bufptr,
							  uint16_t				size
							  );

#ifdef __cplusplus
}
#endif

#endif	//	RSCIP_H_
