/**
 ****************************************************************************************
 * DISCLAIMER
 ****************************************************************************************
 * This software and/or information (the "Material") is supplied by Renesas Electronics
 * Corporation. and is only intended for use with Renesas products. No other uses are authorized.
 * The Material is owned by Renesas Electronics Corporation and is protected under all applicable laws,
 * including copyright laws.
 * THIS MATERIAL IS PROVIDED "AS IS," AND RENESAS MAKES NO WARRANTIES REGARDING THIS MATERIAL,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
 * TO THE MAXIMUM EXTENT PERMITTED BY LAW, NEITHER RENESAS ELECTRONICS CORP. NOR ANY OF ITS
 * AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS MATERIAL, EVEN IF RENESAS OR ITS AFFILIATES
 * HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this Material
 * and to discontinue its availability
 *
 ****************************************************************************************
 *
 * @file        app.c
 *
 * @brief       rBLE Sample Application
 *
 * Copyright(C) 2013-2016 Renesas Electronics Corporation
 *
 * $Rev: 6128 $
 *
 ****************************************************************************************
 */
#include    "db_handle.h"
#include    "tx_api.h"
#include    "ble_app_thread.h"
#include    <stdio.h>
#include    <string.h>
#include    <stdlib.h>
#include    <stdbool.h>
#include    "rble.h"
#include    "rble_app.h"
#include    "rble_api_custom.h"
#include    "rscip_ext.h"

#include    "prf_sel.h"
#include    "tx_api.h"
#include    "application_dispatcher_thread.h"
#include    "common.h"

#ifndef char_t
typedef char            char_t;
#endif

#define ENABLE_SET_NAME

#ifdef ENABLE_SET_NAME
#define DEVICE_NAME "Renesas HC Demo"
#endif
/**************************** Define Declaration **************************************/
#define     RUN_COMMAND_QUEUE_SIZE          10
#define     ILLEGAL_CONNECTION_HANDLE       0xffff

enum RBLE_APP_CMD_NO_enum {
    RBLE_APP_CMD_NON,
    GAP_RESET_CMD,
    GAP_SET_NAME_CMD,
    GAP_OBSERVATION_ENABLE_CMD,
    GAP_OBSERVATION_DISABLE_CMD,
    GAP_BROADCAST_ENABLE_CMD,
    GAP_BROADCAST_DISABLE_CMD,
    GAP_SET_BONDING_MODE_CMD,
    GAP_SET_SECURITY_REQUEST_CMD,
    GAP_GET_DEVICE_INFO_CMD,
    GAP_GET_WHITE_LIST_SIZE_CMD,
    GAP_ADD_TO_WHITE_LIST_CMD,
    GAP_DEL_FROM_WHITE_LIST_CMD,
    GAP_GET_REMOTE_DEVICE_NAME_CMD,
    GAP_GET_REMOTE_DEVICE_INFO_CMD,
    GAP_DEVICE_SEARCH_CMD,
    GAP_SET_RECONNECT_ADDRESS_CMD,
    GAP_SET_RANDOM_ADDRESS_CMD,
    GAP_SET_PRIVACY_FEATURE_CMD,
    GAP_SET_PERIPHERAL_PRIVACY_FEATURE_CMD,
    GAP_CREATE_CONNECTION_CMD,
    GAP_CONNECTION_CANCEL_CMD,
    GAP_DISCONNECT_CMD,
    GAP_START_BONDING_CMD,
    GAP_BONDING_INFO_IND_CMD,
    GAP_BONDING_RESPONSE_CMD,
    GAP_CHANGE_CONNECTION_PARAM_CMD,
    GAP_CHANNEL_MAP_REQ_CMD,
    GAP_READ_RSSI_CMD,
    GAP_AUTHORIZED_IND_CMD,

    SM_SET_KEY_CMD,
    SM_START_ENC_CMD,
    SM_TK_REQ_RESP_CMD,
    SM_LTK_REQ_RESP_CMD,
    SM_IRK_REQ_RESP_CMD,
    SM_CSRK_REQ_RESP_CMD,
    SM_CHK_BD_ADDR_REQ_RESP_CMD,

    GATT_ENABLE_CMD,
    GATT_DISCOVERY_SERVICE_REQUEST_CMD,
    GATT_DISCOVERY_CHAR_REQUEST_CMD,
    GATT_DISCOVERY_CHAR_DESCRIPTOR_REQUEST_CMD,
    GATT_READ_CHAR_REQUEST_CMD,
    GATT_WRITE_CHAR_REQUEST_CMD,
    GATT_WRITE_RELIABLE_REQUEST_CMD,
    GATT_EXECUTE_WRITE_CHAR_REQUEST_CMD,
    GATT_NOTIFY_REQUEST_CMD,
    GATT_INDICATE_REQUEST_CMD,
    GATT_WRITE_RESPONSE_CMD,
    GATT_SET_PERMISSION_CMD,
    GATT_SET_DATA_CMD,

/* --------------------------- Find Me Profile ---------------------------------------*/
    FMP_Target_Enable_CMD,
    FMP_Target_Disable_CMD,
    FMP_Locator_Enable_CMD,
    FMP_Locator_Disable_CMD,
    FMP_Locator_Set_Alert_CMD,

/* ------------------------- Health Thermometer Profile-------------------------------*/
    HTP_Thermometer_Enable_CMD,
    HTP_Thermometer_Disable_CMD,
    HTP_Thermometer_Send_Temp_CMD,
    HTP_Thermometer_Req_Measurement_Period_Ind_CMD,
    HTP_Collector_Enable_CMD,
    HTP_Collector_Disable_CMD,
    HTP_COLLECTOR_READ_CHAR_CMD,
    HTP_COLLECTOR_WRITE_CHAR_CMD,
    HTP_Collector_Set_Measurement_Period_CMD,

/* ------------------------- Proximity Profile---------------------------------------*/
    PXP_Reporter_Enable_CMD,
    PXP_Reporter_Disable_CMD,
    PXP_Monitor_Enable_CMD,
    PXP_Monitor_Disable_CMD,
    PXP_Monitor_Get_Alert_Level_CMD,
    PXP_Monitor_Set_Alert_Level_CMD,
    PXP_Monitor_Get_Tx_Power_CMD,

/* ------------------------- Blood Pressure Profile-------------------------------*/
    BLP_Sensor_Enable_CMD,
    BLP_Sensor_Disable_CMD,
    BLP_Sensor_Send_Measurements_CMD,
    BLP_Collector_Enable_CMD,
    BLP_Collector_Disable_CMD,
    BLP_Collector_Read_Char_CMD,
    BLP_Collector_Write_Char_CMD,

/* ------------------------- HID over GATT Profile-------------------------------*/
    HGP_HDevice_Enable_CMD,
    HGP_HDevice_Disable_CMD,
    HGP_HDevice_Send_Report_CMD,
    HGP_HDevice_Send_Battery_Level_CMD,
    HGP_BHost_Enable_CMD,
    HGP_BHost_Disable_CMD,
    HGP_BHost_Read_Char_CMD,
    HGP_BHost_Read_By_UUID_Char_CMD,
    HGP_BHost_Write_Char_CMD,
    HGP_BHost_Set_Report_CMD,
    HGP_BHost_Write_Protocol_Mode_CMD,
    HGP_BHost_Data_Output_CMD,
    HGP_RHost_Enable_CMD,
    HGP_RHost_Disable_CMD,
    HGP_RHost_Read_Char_CMD,
    HGP_RHost_Read_By_UUID_Char_CMD,
    HGP_RHost_Read_Long_Char_CMD,
    HGP_RHost_Write_Char_CMD,
    HGP_RHost_Set_Report_CMD,
    HGP_RHost_Write_Protocol_Mode_CMD,
    HGP_RHost_Data_Output_CMD,
    HGP_RHost_Write_Control_Point_CMD,

/* ------------------------- Scan Parameters Profeils-------------------------------*/
    SPP_Server_Enable_CMD,
    SPP_Server_Disable_CMD,
    SPP_Server_Send_Refresh_CMD,
    SPP_Client_Enable_CMD,
    SPP_Client_Disable_CMD,
    SPP_Client_Write_Char_CMD,
    SPP_Client_Write_Interval_CMD,

/* ------------------------- Heart Rate Profile-------------------------------*/
    HRP_Sensor_Enable_CMD,
    HRP_Sensor_Disable_CMD,
    HRP_Sensor_Send_Measurements_CMD,
    HRP_Collector_Enable_CMD,
    HRP_Collector_Disable_CMD,
    HRP_Collector_Read_Char_CMD,
    HRP_Collector_Write_Control_Point_CMD,
    HRP_Collector_Write_Char_CMD,

/* ------------------------- Cycling Speed and Cadence Profile-------------------------------*/
    CSCP_Sensor_Enable_CMD,
    CSCP_Sensor_Disable_CMD,
    CSCP_Sensor_Send_Measurements_CMD,
    CSCP_Sensor_Send_Sc_Control_Point_CMD,
    CSCP_Collector_Enable_CMD,
    CSCP_Collector_Disable_CMD,
    CSCP_Collector_Read_Char_CMD,
    CSCP_Collector_Write_Sc_Control_Point_CMD,
    CSCP_Collector_Write_Char_CMD,

/* ------------------------- Glucose Profile-------------------------------*/
    GLP_Sensor_Enable_CMD,
    GLP_Sensor_Disable_CMD,
    GLP_Sensor_Send_Measurements_CMD,
    GLP_Sensor_Send_Measurements_Context_CMD,
    GLP_Sensor_Send_Ra_Control_Point_CMD,
    GLP_Collector_Enable_CMD,
    GLP_Collector_Disable_CMD,
    GLP_Collector_Read_Char_CMD,
    GLP_Collector_Write_Ra_Control_Point_CMD,
    GLP_Collector_Write_Char_CMD,

/* ------------------------- Cycling Power Profeils-------------------------------*/
    CPP_Sensor_Enable_CMD,
    CPP_Sensor_Disable_CMD,
    CPP_Sensor_Send_Measurements_CMD,
    CPP_Sensor_Broadcast_Measurements_CMD,
    CPP_Sensor_Send_Vector_CMD,
    CPP_Sensor_Send_CP_Control_Point_CMD,
    CPP_Sensor_Send_Battery_Level_CMD,
    CPP_Sensor_Send_Write_Response_CMD,
    CPP_Collector_Enable_CMD,
    CPP_Collector_Disable_CMD,
    CPP_Collector_Read_Char_CMD,
    CPP_Collector_Write_CP_Control_Point_CMD,
    CPP_Collector_Write_Char_CMD,

/* ------------------------- Time Profile-------------------------------*/
    TIP_Server_Enable_CMD,
    TIP_Server_Disable_CMD,
    TIP_Server_Send_Current_Time_CMD,
    TIP_Server_Write_Data_CMD,
    TIP_Client_Enable_CMD,
    TIP_Client_Disable_CMD,
    TIP_Client_Read_Char_CMD,
    TIP_Client_Write_Char_CMD,
    TIP_Client_Write_Time_Update_CP_CMD,

    /* ------------------------- ANP Profile-------------------------------*/
    ANP_Server_Enable_CMD,
    ANP_Server_Disable_CMD,
    ANP_Server_Send_New_Alert_CMD,
    ANP_Server_Send_Unread_Alert_CMD,
    ANP_Client_Enable_CMD,
    ANP_Client_Disable_CMD,
    ANP_Client_Read_Char_CMD,
    ANP_Client_Write_Alert_Notification_CP_CMD,
    ANP_Client_Write_Char_CMD,

    /* ------------------------- LNP Profile-------------------------------*/
    LNP_Sensor_Enable_CMD,
    LNP_Sensor_Disable_CMD,
    LNP_Sensor_Send_Location_Speed_CMD,
    LNP_Sensor_Set_Position_Quality_CMD,
    LNP_Sensor_Send_LN_Control_Point_CMD,
    LNP_Sensor_Send_Navigation_CMD,
    LNP_Sensor_Send_Battery_Level_CMD,
    LNP_Collector_Enable_CMD,
    LNP_Collector_Disable_CMD,
    LNP_Collector_Read_Char_CMD,
    LNP_Collector_Write_LN_Control_Point_CMD,
    LNP_Collector_Write_Char_CMD,

    /* ------------------------- Phone Alert Status Profile-------------------------------*/
    PASP_Server_Enable_CMD,
    PASP_Server_Disable_CMD,
    PASP_Server_Send_Alert_Status_CMD,
    PASP_Server_Send_Ringer_Setting_CMD,
    PASP_Client_Enable_CMD,
    PASP_Client_Disable_CMD,
    PASP_Client_Read_Char_CMD,
    PASP_Client_Write_Ringer_Control_Point_CMD,
    PASP_Client_Write_Char_CMD,

    /* ------------------------- Running Speed and Cadence Profile-------------------------------*/
    RSCP_Sensor_Enable_CMD,
    RSCP_Sensor_Disable_CMD,
    RSCP_Sensor_Send_Measurements_CMD,
    RSCP_Sensor_Send_SC_Control_Point_CMD,
    RSCP_Collector_Enable_CMD,
    RSCP_Collector_Disable_CMD,
    RSCP_Collector_Read_Char_CMD,
    RSCP_Collector_Write_SC_Control_Point_CMD,
    RSCP_Collector_Write_Char_CMD,

/* ------------------------- Sample Custom Profile-------------------------------*/
    SCP_Sensor_Enable_CMD,
    SCP_Sensor_Disable_CMD,
    SCP_Sensor_Send_Notify_CMD,
    SCP_Sensor_Send_Indicate_CMD,
    SCP_Collector_Enable_CMD,
    SCP_Collector_Disable_CMD,
    SCP_Collector_Read_Char_CMD,
    SCP_Collector_Write_Char_CMD,

/* ------------------------- Vendor Specific-------------------------------*/
    VS_Enable_CMD,
    VS_Test_Rx_Start_CMD,
    VS_Test_Tx_Start_CMD,
    VS_Test_End_CMD,
    VS_Test_Set_Parameter_CMD,
    VS_Test_Read_RSSI_CMD,
    VS_Write_BdAddress_CMD,
    VS_Set_Tx_Power_CMD,
    VS_GPIO_Dir_CMD,
    VS_GPIO_Access_CMD,
    VS_Flash_Management_CMD,
    VS_Flash_Access_CMD,
    VS_Flash_Operation_CMD,
    VS_Flash_Get_Space_CMD,
    VS_Flash_Get_Eel_Ver_CMD,
    VS_Adapt_Enable_CMD,
    VS_Set_Params_CMD,

    EXIT_CMD
};

enum APP_KEY_FLAG_enum {
    APP_LTK,
    APP_ENCKEY,
    APP_IDKEY,
    APP_SIGNKEY
};

typedef struct {
    uint8_t                         Key_Set_Flags;
    struct RBLE_EVT_SM_Key_t        EncKey;
    struct RBLE_EVT_SM_Key_t        IrKey;
    struct RBLE_EVT_SM_Key_t        SignKey;
} APP_KEY_DATA;

typedef enum {
    APP_DISP_EVT,
    APP_DISP_CMD,
    APP_DISP_STATUS,
    APP_DISP_FATAL,
    APP_DISP_PASSKEY,
} APP_DISP_TYPE;

#if !defined(USE_Synergy_LCD) && !defined(USE_PAIRING_JUSTWORKS)
#error "Passkey requires LCD, so when LCD function is not defined, need to define USE_PAIRING_JUSTWORKS."
#endif
/******************************* PRIVATE PROTOTYPE ************************************/
RBLE_STATUS APP_Run( uint32_t run_command );

static void APP_RBLE_CallBack( RBLE_MODE mode );
static bool APP_RBLE_Active_CallBack( void );
static bool APP_RBLE_Exit_CallBack( void );

/* --------------------------- Generic Access Profile --------------------------------*/
static RBLE_STATUS APP_GAP_Reset_Command();
static RBLE_STATUS APP_GAP_Set_Name_Command( void );
static RBLE_STATUS APP_GAP_Broadcast_Enable_Command();
static RBLE_STATUS APP_GAP_Set_Bonding_Mode_Command();
static RBLE_STATUS APP_GAP_Set_Security_Request_Command();
static RBLE_STATUS APP_GAP_Bonding_Response_Command();
static RBLE_STATUS APP_GAP_Disconnection_Command( void );
static RBLE_STATUS APP_GAP_Get_Device_Info_Command( void );

static void APP_GAP_CallBack( RBLE_GAP_EVENT *event );
static bool APP_GAP_Reset_CallBack( RBLE_GAP_EVENT *event );
static BOOL APP_GAP_Set_Name_CallBack( RBLE_GAP_EVENT *event );
static bool APP_GAP_Broadcast_Enable_CallBack( RBLE_GAP_EVENT *event );
static bool APP_GAP_Connection_CallBack( RBLE_GAP_EVENT *event );
static bool APP_GAP_Disconnection_CallBack( RBLE_GAP_EVENT *event );
static bool APP_GAP_Bonding_Callback( RBLE_GAP_EVENT *event );
static bool APP_GAP_Set_Bonding_Mode_CallBack( RBLE_GAP_EVENT *event );
static bool APP_GAP_Set_Security_Request_CallBack( RBLE_GAP_EVENT *event );
static bool APP_GAP_RPA_Resolved_CallBack( RBLE_GAP_EVENT *event );
static bool APP_GAP_Bonding_Request_CallBack( RBLE_GAP_EVENT *event );
static bool APP_GAP_Get_Device_Info_CallBack(RBLE_GAP_EVENT *event );

/* ----------------------------- Security Manager ------------------------------------*/
static RBLE_STATUS APP_SM_Check_BDAddr_Response_Command();
static RBLE_STATUS APP_SM_TK_Response_Command();
static RBLE_STATUS APP_SM_LTK_Response_Command();
static RBLE_STATUS APP_SM_IRK_Response_Command();

static void APP_SM_CallBack( RBLE_SM_EVENT *event );
static bool APP_SM_Encryption_Start_Callback( RBLE_SM_EVENT *event );
static bool APP_SM_TK_Request_CallBack( RBLE_SM_EVENT *event );
static bool APP_SM_LTK_Request_CallBack( RBLE_SM_EVENT *event );
static bool APP_SM_IRK_Request_CallBack( RBLE_SM_EVENT *event );
static bool APP_SM_Key_CallBack( RBLE_SM_EVENT *event );
static bool APP_SM_BDAddr_Check_Request_CallBack( RBLE_SM_EVENT *event );

/* ------------------------- Sample Custom Profile-------------------------------*/
static RBLE_STATUS APP_SCPS_Enable_Command();
static RBLE_STATUS APP_SCPS_Send_Notify_Command();
static RBLE_STATUS APP_SCPS_Send_Indicate_Command( void );

static void APP_SCPS_CallBack( RBLE_SCPS_EVENT *event );
static bool APP_SCPS_Enable_CallBack( RBLE_SCPS_EVENT *event );
static bool APP_SCPS_Change_Characteristic_CallBack( RBLE_SCPS_EVENT *event );
static bool APP_SCPS_Send_Notify_CallBack( RBLE_SCPS_EVENT *event );
static bool APP_SCPS_Change_NtfInd_Config_CallBack( RBLE_SCPS_EVENT *event );
static bool APP_SCPS_Send_Indicate_CallBack( RBLE_SCPS_EVENT *event );

/* --------------------------------- Utility -----------------------------------------*/
static void APP_Set_RunCmd( uint32_t cmd );
static bool APP_Compare_BDAddr(RBLE_BD_ADDR* a, RBLE_BD_ADDR* b);
static int_t APP_Get_Random( void );
static void  APP_RBLE_Exit_Command( void );
void g_timer0_start();
/* ------------------------- Vendor Specific Profile-------------------------------*/
static RBLE_STATUS APP_VS_Enable_Command( void );
static RBLE_STATUS APP_VS_Write_BdAddress_Command( void );
static RBLE_STATUS APP_VS_Flash_Management_Command( void );
#if _DBG_
static RBLE_STATUS APP__VS_Flash_Access_Command( void );
#endif
static void APP_VS_CallBack( RBLE_VS_EVENT *event );
static bool APP_VS_Write_Bd_Address_Callback( RBLE_VS_EVENT *event );
static bool APP_VS_Flash_Management_Callback( RBLE_VS_EVENT *event );
#if DBG_
static bool APP_VS_Flash_Access_Callback(RBLE_VS_EVENT *event );
#endif

// TODO: change over to console output
#define APP_Disp_Clear()       //printf("clear")
#define APP_Disp(x, s)         //printf("%s", s)
#define APP_Disp_Status(x)     //printf("%d", x)
#define APP_Disp_PassKey(x)    //printf("%d", x)
#define APP_Disp_RW(c)         //printf("%c", c)


void activity_notification(activity_data  *data);
void healthcare_notification(activity_data  *data);
uint32_t Reverse32( const uint32_t val );
void App_send_message( uint8_t         CharValue);
void update_BdAddress(uint8_t *ptr);
void APP_Disconnect(void);
bool APP_Init( void );
char_t* eventId2String(uint16_t event);

/**************************** PUBLIC Memory Declaration *******************************/

/**************************** PRIVATE Memory Declaration ******************************/
static uint16_t         ConnectionHdl = ILLEGAL_CONNECTION_HANDLE;
static bool             InBonding     = false;
static RBLE_BD_ADDR     BondedAddr    ;
static uint8_t          SecStatus     ;
static APP_KEY_DATA     LocalKey      ;
static APP_KEY_DATA     RemoteKey     ;
static uint8_t          ConnectionIdx ;
static uint8_t          ConnectionType;
static RBLE_BD_ADDR     RemoteDevice  ;
static bool             FoundFlg      ;
static bool             CheckedIrkFlg ;


static uint8_t          Flash_cmd = NULL;
static RBLE_BD_ADDR BdAddress = {{ 0x45, 0x01, 0xDE, 0xFA, 0xFE, 0xCA }};

static struct  
{
    uint16_t DataEvent;
	uint16_t DataValArr16[8];
} DataVal;

static TX_TIMER         RBLE_App_Timer;
static uint8_t          Notify_On_count = 0;

#if 0
extern RBLE_MODE		rble_mode;
#endif
/******************************* Program Area *****************************************/

/******************************* Program Area *****************************************/
/******************************************************************************************/
/**
 *  @brief      Application RBLE Exit Command Execute
 *
 *  @retval     None
 */
/******************************************************************************************/
/*
 * Updating the Unique ID of the Chip for the Board ID. This Gives the Unique ID for the RL78/G1D BLE
 */
void update_BdAddress(uint8_t *ptr)
{
    uint8_t i=0;

    for( i=0; i <6; i++){
        BdAddress.addr[i]= *ptr++;
    }
}
static void  APP_RBLE_Exit_Command( void )
{
    // trap when exit
    while (1)
    {
        /* show message to power cycle or reset to RL78/G1D device */

    }
}
/******************************************************************************************/
/**
 *  @brief      Application Vendor Specific Flash Enable Command Execute
 *
 *  @retval     None
 */
/******************************************************************************************/
static RBLE_STATUS APP_VS_Enable_Command( void )
{
    RBLE_STATUS     ret_status;

    /* API Call */
    ret_status = RBLE_VS_Enable( &APP_VS_CallBack );

    return( ret_status );
}

/**************************************************************************************/
/**
 *  @brief      rBLE API Call : Vendor Specific Write BD Address (Public)
 *
 *  @retval     rBLE API Return Status
 */
/******************************************************************************************/
static RBLE_STATUS APP_VS_Write_BdAddress_Command( void )
{
    RBLE_STATUS     ret_status;

    /* API Call */
    ret_status = RBLE_VS_Write_Bd_Address( &BdAddress );
    return( ret_status );
}

/**************************************************************************************/
/**
 *  @brief      rBLE API Call : Vendor Specific Flash Management
 *
 *  @retval     rBLE API Return Status
 */
/******************************************************************************************/
static RBLE_STATUS APP_VS_Flash_Management_Command( void )
{
    RBLE_STATUS     ret_status;

    /* API Call */
    ret_status = RBLE_VS_Flash_Management( Flash_cmd );

    return( ret_status );
}
/**************************************************************************************/
/**
 *  @brief      rBLE API Call : GAP Device Info
 *
 *  @retval     rBLE API Return Status
 */
/******************************************************************************************/
static RBLE_STATUS APP_GAP_Get_Device_Info_Command( void )
{
    RBLE_STATUS ret_status;

    /* API Call */
    ret_status = RBLE_GAP_Get_Device_Info();

    return( ret_status );
}

/******************************************************************************************/
/**
 *  @brief      Event Handler : Vendor Specific Event
 *
 *  @param      event   Vendor Specific Event Parameters
 *
 *  @retval     None
 */
/******************************************************************************************/
static void APP_VS_CallBack( RBLE_VS_EVENT *event )
{
    switch( event->type ) {

        case RBLE_VS_EVENT_WR_BD_ADDR_COMP:
            APP_VS_Write_Bd_Address_Callback( event );
            break;
        case RBLE_VS_EVENT_FLASH_MANAGEMENT_COMP:
            APP_VS_Flash_Management_Callback( event );
            break;
        default:
            break;
    }
}

/******************************************************************************************/
/**
 *  @brief      Event Handler : Vendor Specific write BD Address callback Event
 *
 *  @param      event   Vendor Specific Event Parameters
 *
 *  @retval     None
 */
/******************************************************************************************/
static bool APP_VS_Write_Bd_Address_Callback(RBLE_VS_EVENT *event )
{
    bool        ret = false;
    if(RBLE_OK == event->param.status) {
        ret = true;
        Flash_cmd = RBLE_VS_FLASH_CMD_STOP;
        APP_Set_RunCmd(VS_Flash_Management_CMD);
    }
    return ( ret );
}

/******************************************************************************************/
/**
 *  @brief      Event Handler : Vendor Specific Flash Management callback Event
 *
 *  @param      event   Vendor Specific Event Parameters
 *
 *  @retval     None
 */
/******************************************************************************************/
static bool APP_VS_Flash_Management_Callback(RBLE_VS_EVENT *event )
{
    bool        ret = false;
    if(RBLE_OK == event->param.management_comp.status) {
        ret = true;
        switch( event->param.management_comp.cmd ) {

            case RBLE_VS_FLASH_CMD_START:
                APP_Set_RunCmd(VS_Write_BdAddress_CMD);
                break;
            case RBLE_VS_FLASH_CMD_STOP:
                APP_Set_RunCmd(EXIT_CMD);   // Exit rBLE Application
                break;
            default:
                break;
        }
    }
    return ( ret );
}

/**************************************************************************************/
/**
 *  @brief      GAP Get Device Info Callback function
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_GAP_Get_Device_Info_CallBack(RBLE_GAP_EVENT *event )
{
    bool        ret = false;
    static RBLE_BD_ADDR BdAddress_Read;

    if(RBLE_OK == event->param.get_dev_ver.status)
    {
        ret = true;
        BdAddress_Read = event->param.get_dev_ver.addr;
        /* compare BD Address */
        if (APP_Compare_BDAddr (&BdAddress_Read, &BdAddress)){
            /* API Call */
            APP_Set_RunCmd(GAP_SET_BONDING_MODE_CMD);
        }
        else{   // write new BD address

            APP_Set_RunCmd(VS_Enable_CMD);
            /* Write BD Address */
            Flash_cmd = RBLE_VS_FLASH_CMD_START;
            APP_Set_RunCmd(VS_Flash_Management_CMD);        // start calling for BD Address write
        }
    }
    return ( ret );
}


/**************************************************************************************/
/**
 *  @brief      Application Initialize
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
bool APP_Init( void )
{
    bool        ret = true;
    RBLE_STATUS ret_status;

    /* Initialize rBLE */
    APP_Disp(APP_DISP_CMD, "BLE Initialization");
    ret_status = RBLE_Init(&APP_RBLE_CallBack);
    if ( RBLE_OK != ret_status ) {
        ret = false;
    }
    
    /* Initialize Bonding Information Buffer */
    SecStatus      = RBLE_SMP_SEC_NONE;
    memset(&BondedAddr, 0, sizeof(RBLE_BD_ADDR));
    memset(&LocalKey  , 0, sizeof(APP_KEY_DATA));
    memset(&RemoteKey , 0, sizeof(APP_KEY_DATA));

    return( ret );
}

/**************************************************************************************/
/**
 *  @brief      Application Command Execute
 *
 *  @retval     None
 */
/******************************************************************************************/
RBLE_STATUS APP_Run( uint32_t run_command )
{
    RBLE_STATUS ret_status;

        switch(run_command)
        {
            case RBLE_APP_CMD_NON:
                break;
            /* --------------------------- Generic Access Profile --------------------------------*/
            case GAP_RESET_CMD:
                ret_status = APP_GAP_Reset_Command();
                break;
#ifdef ENABLE_SET_NAME
            case GAP_SET_NAME_CMD:
                ret_status = APP_GAP_Set_Name_Command();
                break;
#endif
            case GAP_BROADCAST_ENABLE_CMD:
                ret_status = APP_GAP_Broadcast_Enable_Command();
                break;
            case GAP_SET_BONDING_MODE_CMD:
                ret_status = APP_GAP_Set_Bonding_Mode_Command();
                break;
            case GAP_SET_SECURITY_REQUEST_CMD:
                ret_status = APP_GAP_Set_Security_Request_Command();
                break;
            case GAP_BONDING_RESPONSE_CMD:
                ret_status = APP_GAP_Bonding_Response_Command();
                break;
            case GAP_DISCONNECT_CMD:
                ret_status = APP_GAP_Disconnection_Command();
                break;
            case GAP_GET_DEVICE_INFO_CMD:
                ret_status = APP_GAP_Get_Device_Info_Command();
                break;
            /* --------------------------- Security Manager -------------------------------------*/
            case SM_CHK_BD_ADDR_REQ_RESP_CMD:
                ret_status = APP_SM_Check_BDAddr_Response_Command();
                break;
            case SM_TK_REQ_RESP_CMD:
                ret_status = APP_SM_TK_Response_Command();
                break;
            case SM_LTK_REQ_RESP_CMD:
                ret_status = APP_SM_LTK_Response_Command();
                break;
            case SM_IRK_REQ_RESP_CMD:
                ret_status = APP_SM_IRK_Response_Command();
                break;

            /* ------------------------- Sample Custom Profile-------------------------------*/
            case SCP_Sensor_Enable_CMD:
                ret_status = APP_SCPS_Enable_Command();

                break;
            case SCP_Sensor_Send_Notify_CMD:
                ret_status = APP_SCPS_Send_Notify_Command();
                break;
		    case SCP_Sensor_Send_Indicate_CMD:
				ret_status = APP_SCPS_Send_Indicate_Command();

				break;

           /* ------------------------- Vendor Specific Profile-------------------------------*/
            case VS_Enable_CMD:
                 ret_status = APP_VS_Enable_Command();
                 break;
            case VS_Write_BdAddress_CMD:
                 ret_status = APP_VS_Write_BdAddress_Command();
                 break;
            case VS_Flash_Management_CMD:
                 ret_status = APP_VS_Flash_Management_Command();
                 break;
            case VS_Flash_Access_CMD:
                 ret_status = APP_VS_Flash_Management_Command();
                 break;

            case EXIT_CMD:
                 APP_RBLE_Exit_Command();
                 ret_status = true;
                 break;

            default:
                ret_status = RBLE_UNSPECIFIED_ERROR;
                break;
        }

    return ret_status;
}

/**************************************************************************************/
/**
 *  @brief      rBLE API Call : GAP Reset
 *
 *  @retval     rBLE API Return Status
 */
/******************************************************************************************/
static RBLE_STATUS APP_GAP_Reset_Command( void )
{
    RBLE_STATUS ret_status;

    ConnectionHdl = ILLEGAL_CONNECTION_HANDLE;
    APP_Disp(APP_DISP_CMD, "Reset");
    ret_status = RBLE_GAP_Reset( &APP_GAP_CallBack, &APP_SM_CallBack );

    return( ret_status );
}

#ifdef ENABLE_SET_NAME
static RBLE_STATUS APP_GAP_Set_Name_Command( void )
{
    RBLE_STATUS ret_status;
    RBLE_BD_NAME dev_name = {.name = {0}, .namelen = 0};

    strncpy((char *)dev_name.name, DEVICE_NAME, sizeof(dev_name.name) - 1);
    dev_name.namelen = (uint8_t)strlen((char *)dev_name.name);

    ret_status = RBLE_GAP_Set_Name(&dev_name);

    return( ret_status );
}
#endif
/**************************************************************************************/
/**
 *  @brief      rBLE API Call : GAP Broadcast Enable
 *
 *  @retval     rBLE API Return Status
 */
/******************************************************************************************/
static RBLE_STATUS APP_GAP_Broadcast_Enable_Command( void )
{
    RBLE_STATUS ret_status;

    APP_Disp(APP_DISP_CMD, "Broadcast Enable");
    ret_status = RBLE_GAP_Broadcast_Enable( RBLE_Broadcast_Enable_Param[0].disc_mode, RBLE_Broadcast_Enable_Param[0].conn_mode, (RBLE_ADV_INFO *)&(RBLE_Broadcast_Enable_Param[0].adv_info) );

    return( ret_status );
}

/**************************************************************************************/
/**
 *  @brief      rBLE API Call : GAP Set Bonding Mode
 *
 *  @retval     rBLE API Return Status
 */
/******************************************************************************************/
static RBLE_STATUS APP_GAP_Set_Bonding_Mode_Command( void )
{
    RBLE_STATUS ret_status;

    APP_Disp(APP_DISP_CMD, "Set Bonding Mode");
    ret_status = RBLE_GAP_Set_Bonding_Mode(RBLE_GAP_BONDABLE);

    return( ret_status );
}

/**************************************************************************************/
/**
 *  @brief      rBLE API Call : GAP Set Security Request
 *
 *  @retval     rBLE API Return Status
 */
/******************************************************************************************/
static RBLE_STATUS APP_GAP_Set_Security_Request_Command( void )
{
    RBLE_STATUS ret_status;

    APP_Disp(APP_DISP_CMD, "Set Security Request");
    ret_status = RBLE_GAP_Set_Security_Request( RBLE_GAP_SEC1_NOAUTH_PAIR_ENC );

    return( ret_status );
}

/**************************************************************************************/
/**
 *  @brief      rBLE API Call : GAP Bonding Response
 *
 *  @retval     rBLE API Return Status
 */
/******************************************************************************************/
static RBLE_STATUS APP_GAP_Bonding_Response_Command( void )
{
    RBLE_STATUS ret_status;
    static RBLE_BOND_RESP_PARAM Param = {
        0x0000,                                         /* Connection handle           */
        RBLE_OK,                                        /* accept or reject bonding    */
        #ifdef USE_PAIRING_JUSTWORKS
        RBLE_IO_CAP_NO_INPUT_NO_OUTPUT,                 /* IO capabilities             */
        #else
        RBLE_IO_CAP_DISPLAY_ONLY,                       /* IO capabilities             */
        #endif
        RBLE_OOB_AUTH_DATA_NOT_PRESENT,                 /* OOB flag                    */
        #ifdef USE_PAIRING_JUSTWORKS
        RBLE_AUTH_REQ_NO_MITM_BOND,                     /* Authentication Requirements */
        #else
        RBLE_AUTH_REQ_MITM_BOND,                        /* Authentication Requirements */
        #endif
        RBLE_SMP_MAX_ENC_SIZE_LEN,                      /* Encryption key size         */
        RBLE_KEY_DIST_ENCKEY | RBLE_KEY_DIST_IDKEY,     /* Initiator key distribution  */
        RBLE_KEY_DIST_ENCKEY,                           /* Responder key distribution  */
        0x00                                            /* Reserved                    */
    };

    Param.conhdl = ConnectionHdl;
    APP_Disp(APP_DISP_CMD, "Bonding Response");
    ret_status = RBLE_GAP_Bonding_Response( &Param );

    return( ret_status );
}

/**************************************************************************************/
/**
 *  @brief      rBLE API Call : GAP Disconnection
 *
 *  @retval     rBLE API Return Status
 */
/******************************************************************************************/
static RBLE_STATUS APP_GAP_Disconnection_Command( void )
{
    RBLE_STATUS ret_status = false;

    if(ConnectionHdl != ILLEGAL_CONNECTION_HANDLE)
    {
        APP_Disp(APP_DISP_CMD, "BLE Disconnect");
        ret_status = RBLE_GAP_Disconnect( ConnectionHdl );
    }

    return( ret_status );
}

/**************************************************************************************/
/**
 *  @brief      rBLE API Call : SM Check BD Address Request Resonse
 *
 *  @retval     rBLE API Return Status
 */
/******************************************************************************************/
static RBLE_STATUS APP_SM_Check_BDAddr_Response_Command( void )
{
    RBLE_STATUS     ret_status;
    uint8_t         sec_status = RBLE_SMP_SEC_NONE;

    if(FoundFlg)
    {
        sec_status = SecStatus;
    }

    APP_Disp(APP_DISP_CMD, "Check BDAddress");
    ret_status = RBLE_SM_Chk_Bd_Addr_Req_Resp(ConnectionIdx, ConnectionType, FoundFlg, sec_status, &BondedAddr);

    return( ret_status );
}

/**************************************************************************************/
/**
 *  @brief      rBLE API Call : SM TK Request Response
 *
 *  @retval     rBLE API Return Status
 */
/******************************************************************************************/
static RBLE_STATUS APP_SM_TK_Response_Command( void )
{
    RBLE_STATUS ret_status;
    static RBLE_KEY_VALUE tk = {
        { 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00  }    /* TK(Temporary Key) */
    };
    uint32_t passkey;
    uint8_t* byteptr = (uint8_t*)&passkey;
    uint8_t  i;

    /* Generate PassKey (range:000,000 - 999,999) */
    passkey  = (uint32_t)APP_Get_Random();
    passkey |= (uint32_t)APP_Get_Random() << 16;
    passkey %= 1000000;

    /* Copy PassKey to TK(Temporary Key) */
    for(i = 0; i < sizeof(uint32_t); i++)
    {
        tk.key[RBLE_KEY_LEN - 1 - i] = byteptr[i];
    }
    APP_Disp(APP_DISP_CMD, "Temporary Key Response");
    APP_Disp_PassKey( passkey );

    ret_status = RBLE_SM_Tk_Req_Resp( ConnectionIdx, RBLE_OK, &tk );

    return( ret_status );
}

/**************************************************************************************/
/**
 *  @brief      rBLE API Call : SM LTK Request Response
 *
 *  @retval     rBLE API Return Status
 */
/******************************************************************************************/
static RBLE_STATUS APP_SM_LTK_Response_Command( void )
{
    RBLE_STATUS   ret_status;
    const uint8_t sec_prop = RBLE_SMP_KSEC_UNAUTH_NO_MITM;
    uint8_t       status   = RBLE_OK;
    int_t         i;

    /* Requested in Bonding Sequence (only in First Connection) */
    if(true == InBonding)
    {
        /* Generate LTK(Long Term Key), Random Number, EDIV(Encrypted Diversifier)  */
        for(i = 0; i <  RBLE_RAND_NB_LEN; i++)
        {
            LocalKey.EncKey.nb.nb[i]   = (uint8_t)APP_Get_Random();
        }
        for(i = 0; i <  RBLE_KEY_LEN; i++)
        {
            LocalKey.EncKey.ltk.key[i] = (uint8_t)APP_Get_Random();
        }
        LocalKey.EncKey.ediv    = (uint16_t)APP_Get_Random();
        LocalKey.Key_Set_Flags |= (1 << APP_ENCKEY);
    }
    /* Requested in Encryption Start Sequence (in Connection After Bonding) */
    else
    {
        /* Tell latest LTK of Previous Connection */

        /* Check if latest LTK is valid */
        if(0u == (LocalKey.Key_Set_Flags & (1 << APP_ENCKEY)))
        {
            status = RBLE_ERR;
        }
    }
    APP_Disp(APP_DISP_CMD, "LTK Response");
    ret_status = RBLE_SM_Ltk_Req_Resp( ConnectionIdx, status, sec_prop,
                                       LocalKey.EncKey.ediv,
                                      &LocalKey.EncKey.nb  ,
                                      &LocalKey.EncKey.ltk );

    return( ret_status );
}

/**************************************************************************************/
/**
 *  @brief      rBLE API Call : SM IRK Request Response
 *
 *  @retval     rBLE API Return Status
 */
/******************************************************************************************/
static RBLE_STATUS APP_SM_IRK_Response_Command( void )
{
    RBLE_STATUS   ret_status;
    uint8_t       status   = RBLE_ERR;
    static RBLE_KEY_VALUE irk = {
        {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}  /* IRK(Identity Resolving Key) */
    };

    if((!CheckedIrkFlg) && (0u != (RemoteKey.Key_Set_Flags & (1 << APP_IDKEY))))
    {
        CheckedIrkFlg = true;
        irk    = RemoteKey.IrKey.ltk;
        status = RBLE_OK            ;
    }

    APP_Disp(APP_DISP_CMD, "IRK Response");
    ret_status = RBLE_SM_Irk_Req_Resp( ConnectionIdx, status, &BondedAddr, &irk, SecStatus );

    return( ret_status );
}

/**************************************************************************************/
/**
 *  @brief      rBLE API Call : SCP Server Enable
 *
 *  @retval     rBLE API Return Status
 */
/******************************************************************************************/
static RBLE_STATUS APP_SCPS_Enable_Command( void )
{
    RBLE_STATUS ret_status;

    static RBLE_SCP_SERVER_PARAM    scps = {
        RBLE_SCP_STOP_NTFIND,       /* Notification configuration (sv1_char1_ntf) */
        RBLE_SCP_STOP_NTFIND,       /* Notification configuration (sv1_char2_ntf) */
    };

    APP_Disp(APP_DISP_CMD, "SCPS Enable");
    ret_status = RBLE_SCP_Server_Enable( ConnectionHdl, RBLE_SCP_CON_CFG, &scps, &APP_SCPS_CallBack );

    return( ret_status );
}

/**************************************************************************************/
/**
 *  @brief      rBLE API Call : SCP Server Send Notification
 *
 *  @retval     rBLE API Return Status
 */
/******************************************************************************************/
static RBLE_STATUS APP_SCPS_Send_Notify_Command( void )
{
    RBLE_STATUS ret_status;
    static RBLE_SCP_NOTIFY_INFO     notify_info = {
        0x0E,                                       /* Length */
        {0x00}                                      /* Data   */
    };

    if (DataVal.DataEvent == ACTIVITY_VAL)
    {
		memcpy(&notify_info.data[0], &DataVal.DataValArr16[0], sizeof(activity_data));
		notify_info.data_len = sizeof(activity_data);
	}
    else if (DataVal.DataEvent == HEALTHCARE_VAL)
    {
		memcpy(&notify_info.data[0], &DataVal.DataValArr16[0], sizeof(activity_data));
		notify_info.data_len = sizeof(activity_data);
	}      	

    if(ConnectionHdl != ILLEGAL_CONNECTION_HANDLE)
   	{
#define DBG 0
#if DBG
        APP_Disp(APP_DISP_CMD, "SCP Server Send Notification");
#endif
	    ret_status = RBLE_SCP_SERVICE1_Server_Send_Notify(ConnectionHdl, DataVal.DataEvent, &notify_info );

    }
    tx_mutex_put(&g_dispatch_mutex);
	
    return( ret_status );
}

/**************************************************************************************/
/**
 *  @brief      rBLE API Call : SCP Server Send Indication
 *
 *  @retval     Kernel Message Status
 */
/******************************************************************************************/
static RBLE_STATUS APP_SCPS_Send_Indicate_Command( void )
{
    RBLE_STATUS ret_status = RBLE_OK;


//    ret_status = RBLE_SCP_SERVICE1_Server_Send_Indicate( ConnectionHdl, (uint8_t) SendCnt_i );

    return(ret_status);
}

/********************  Call Back API ********************/

/******************************************************************************************/
/**
 *  @brief      Event Handle : rBLE
 *
 *  @param      mode    rBLE Mode , defined by RBLE_MODE_enum
 *
 *  @retval     None
 */
/******************************************************************************************/
static void APP_RBLE_CallBack( RBLE_MODE mode )
{
    switch(mode){
        case RBLE_MODE_INITIALIZE:
            break;
        case RBLE_MODE_ACTIVE:
            APP_RBLE_Active_CallBack();
            break;
        case RBLE_MODE_RESET:
            break;
        case RBLE_MODE_SLEEP:
            break;
        case RBLE_MODE_ERROR:
            APP_RBLE_Exit_CallBack();
            break;
        default:
            break;
    }
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : rBLE Active Event
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_RBLE_Active_CallBack( void )
{
    APP_Disp(APP_DISP_EVT, "BLE Active");
    APP_Set_RunCmd(GAP_RESET_CMD);
    return( true );
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : rBLE Exit Event
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_RBLE_Exit_CallBack( void )
{
    APP_Disp(APP_DISP_FATAL, "Fatal");
    return( true );
}

/* --------------------------- Generic Access Profile --------------------------------*/

/******************************************************************************************/
/**
 *  @brief      Event Handler : GAP Event
 *
 *  @param      event   GAP Event Parameters
 *
 *  @retval     None
 */
/******************************************************************************************/
static void APP_GAP_CallBack( RBLE_GAP_EVENT *event )
{
    switch( event->type ) {
        case RBLE_GAP_EVENT_RESET_RESULT:
            APP_GAP_Reset_CallBack( event );
            break;
        case RBLE_GAP_EVENT_SET_NAME_COMP:
#ifdef ENABLE_SET_NAME
            APP_GAP_Set_Name_CallBack( event );
#endif
            break;
        case RBLE_GAP_EVENT_OBSERVATION_ENABLE_COMP:
            break;
        case RBLE_GAP_EVENT_OBSERVATION_DISABLE_COMP:
            break;
        case RBLE_GAP_EVENT_BROADCAST_ENABLE_COMP:
            APP_GAP_Broadcast_Enable_CallBack( event );
            break;
        case RBLE_GAP_EVENT_BROADCAST_DISABLE_COMP:
            break;
        case RBLE_GAP_EVENT_SET_BONDING_MODE_COMP:
            APP_GAP_Set_Bonding_Mode_CallBack( event );
            break;
        case RBLE_GAP_EVENT_SET_SECURITY_REQUEST_COMP:
            APP_GAP_Set_Security_Request_CallBack( event );
            break;
        case RBLE_GAP_EVENT_GET_DEVICE_INFO_COMP:
            APP_GAP_Get_Device_Info_CallBack( event );
            break;
        case RBLE_GAP_EVENT_RPA_RESOLVED:
            APP_GAP_RPA_Resolved_CallBack( event );
            break;
        case RBLE_GAP_EVENT_GET_WHITE_LIST_SIZE_COMP:
            break;
        case RBLE_GAP_EVENT_ADD_TO_WHITE_LIST_COMP:
            break;
        case RBLE_GAP_EVENT_DEL_FROM_WHITE_LIST_COMP:
            break;
        case RBLE_GAP_EVENT_GET_REMOTE_DEVICE_NAME_COMP:
            break;
        case RBLE_GAP_EVENT_GET_REMOTE_DEVICE_INFO_COMP:
            break;
        case RBLE_GAP_EVENT_DEVICE_SEARCH_COMP:
            break;
        case RBLE_GAP_EVENT_DEVICE_SEARCH_RESULT_IND:
            break;
        case RBLE_GAP_EVENT_SET_RANDOM_ADDRESS_COMP:
            break;
        case RBLE_GAP_EVENT_SET_PRIVACY_FEATURE_COMP:
            break;
        case RBLE_GAP_EVENT_CONNECTION_COMP:
            APP_GAP_Connection_CallBack( event );
            break;
        case RBLE_GAP_EVENT_CONNECTION_CANCEL_COMP:
            break;
        case RBLE_GAP_EVENT_DISCONNECT_COMP:
            APP_GAP_Disconnection_CallBack( event );
            break;
        case RBLE_GAP_EVENT_ADVERTISING_REPORT_IND:
            break;
        case RBLE_GAP_EVENT_BONDING_COMP:
            APP_GAP_Bonding_Callback( event );
            break;
        case RBLE_GAP_EVENT_BONDING_REQ_IND:
            APP_GAP_Bonding_Request_CallBack( event );
            break;
        case RBLE_GAP_EVENT_CHANGE_CONNECTION_PARAM_REQ_IND:
            break;
        case RBLE_GAP_EVENT_CHANGE_CONNECTION_PARAM_COMP:
            break;
        case RBLE_GAP_EVENT_CHANGE_CONNECTION_PARAM_RESPONSE:
            break;
        case RBLE_GAP_EVENT_CHANNEL_MAP_REQ_COMP:
            break;
        case RBLE_GAP_EVENT_READ_RSSI_COMP:
            break;
        case RBLE_GAP_EVENT_WR_CHAR_IND:
            break;
        case RBLE_GAP_EVENT_COMMAND_DISALLOWED_IND:
            break;
        default:
            break;
    }
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : GAP Reset Complete Event
 *
 *  @param      event   GAP Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_GAP_Reset_CallBack( RBLE_GAP_EVENT *event )
{
    RBLE_STATUS     ret_status = false;

    if(RBLE_OK == event->param.status) {
        ret_status = true;


        /* Get Device Info */
        APP_Set_RunCmd(GAP_GET_DEVICE_INFO_CMD);

    }

    APP_Disp(APP_DISP_EVT, "Reset Complete");
    APP_Disp_Status(event->param.status);
    return( ret_status );
}

#ifdef ENABLE_SET_NAME
static BOOL APP_GAP_Set_Name_CallBack( RBLE_GAP_EVENT *event )
{
    RBLE_STATUS     ret_status = FALSE;

    if(RBLE_OK == event->param.status) {
        ret_status = TRUE;

        /* Enable Broadcast */
        APP_Set_RunCmd(GAP_BROADCAST_ENABLE_CMD);
    }

    return( ret_status );
}
#endif
/******************************************************************************************/
/**
 *  @brief      Event Respond : GAP Broadcast Enable Complete Event
 *
 *  @param      event   GAP Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_GAP_Broadcast_Enable_CallBack( RBLE_GAP_EVENT *event )
{
    RBLE_STATUS     ret_status = false;

    if(RBLE_OK == event->param.status) {
        ret_status = true;
    }

    APP_Disp(APP_DISP_EVT, "Broadcast Enable");
    APP_Disp_Status(event->param.status);
    return( ret_status );
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : GAP Connection Complete Event
 *
 *  @param      event   GAP Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_GAP_Connection_CallBack( RBLE_GAP_EVENT *event )
{
    RBLE_STATUS ret_status = false;

    if(RBLE_OK == event->param.status) {
        ConnectionHdl  = event->param.conn_comp.connect_info.conhdl;
        RemoteDevice   = event->param.conn_comp.connect_info.peer_addr;
        FoundFlg       = false;
        CheckedIrkFlg  = false;
        ret_status = true;

        /* Enable Profile (Profile is Disabled automatically when Disconnection) */
        APP_Set_RunCmd(SCP_Sensor_Enable_CMD);

        Notify_On_count = 0;
    }

    APP_Disp(APP_DISP_EVT, "Connection Complete");
    APP_Disp_Status(event->param.status);
    return( ret_status );
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : GAP Disconnection Complete Event
 *
 *  @param      event   GAP Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_GAP_Disconnection_CallBack( RBLE_GAP_EVENT *event )
{
    (void) ((event));
    ConnectionHdl = ILLEGAL_CONNECTION_HANDLE;

    /* Disable timer for Notification trigger */
    tx_timer_deactivate(&RBLE_App_Timer);



    APP_Disp(APP_DISP_EVT, "Disconnection Complete");
    APP_Disp_Status(event->param.disconnect.status);
    APP_Disp_Clear();
    /* Restart Broadcast for the Next Connection */
    APP_Set_RunCmd(GAP_BROADCAST_ENABLE_CMD);
    return( true );
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : GAP Set Bonding Mode Complete Event
 *
 *  @param      event   GAP Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_GAP_Set_Bonding_Mode_CallBack( RBLE_GAP_EVENT *event )
{
    RBLE_STATUS ret_status = false;

    if(RBLE_OK == event->param.status) {
        ret_status = true;

        /* Set Security Request */
        APP_Set_RunCmd(GAP_SET_SECURITY_REQUEST_CMD);
    }

    APP_Disp(APP_DISP_EVT, "Bonding Mode Complete");
    APP_Disp_Status(event->param.status);
    return( ret_status );
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : GAP Set Security Request Event
 *
 *  @param      event   GAP Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_GAP_Set_Security_Request_CallBack( RBLE_GAP_EVENT *event )
{
    RBLE_STATUS ret_status = false;

    if(RBLE_OK == event->param.set_sec_req.status) {
        ret_status = true;
#ifdef ENABLE_SET_NAME
        /* Set Name */
        APP_Set_RunCmd(GAP_SET_NAME_CMD);
#else
        /* Start Broadcast for the First Connection */
        APP_Set_RunCmd(GAP_BROADCAST_ENABLE_CMD);
#endif
    }

    APP_Disp(APP_DISP_EVT, "Set Security Request");
    APP_Disp_Status(event->param.set_sec_req.status);
    return( ret_status );
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : GAP RPA Resolved Event
 *
 *  @param      event   GAP Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_GAP_RPA_Resolved_CallBack( RBLE_GAP_EVENT *event )
{
    if(event != NULL){
        APP_Disp(APP_DISP_EVT, "RPA Resolved");
        return( true );
    }
    return( false);
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : GAP Bonding Complete Event
 *
 *  @param      event   GAP Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_GAP_Bonding_Callback( RBLE_GAP_EVENT *event )
{
    InBonding      = false;
    SecStatus      = event->param.bonding_comp.sec_prop | RBLE_SMP_BONDED;
    BondedAddr     = RemoteDevice  ;
    if(event != NULL){
        APP_Disp(APP_DISP_EVT, "Bonding Complete");
        APP_Disp_Status(RBLE_OK);
        return( true );
    }
    return( false );
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : GAP Bonding Request Event
 *
 *  @param      event   GAP Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_GAP_Bonding_Request_CallBack( RBLE_GAP_EVENT *event )
{
    InBonding = true;
    if(event != NULL){
    /* Reset Remote Device Property */
    SecStatus      = RBLE_SMP_SEC_NONE;
    memset(&BondedAddr, 0, sizeof(RBLE_BD_ADDR));
    memset(&LocalKey  , 0, sizeof(APP_KEY_DATA));
    memset(&RemoteKey , 0, sizeof(APP_KEY_DATA));

    /* Reply Bonding Response */
    APP_Set_RunCmd(GAP_BONDING_RESPONSE_CMD);
    APP_Disp(APP_DISP_EVT, "Bonding Request");
    return( true );
    }
    return( false );
}

/* --------------------------- Security Manager -------------------------------------*/

/******************************************************************************************/
/**
 *  @brief      Event Handler : SM Event
 *
 *  @param      event   SM Event Parameters
 *
 *  @retval     None
 */
/******************************************************************************************/
static void APP_SM_CallBack( RBLE_SM_EVENT *event )
{
    switch( event->type ){
        case RBLE_SM_EVENT_SET_CNF:
            break;
        case RBLE_SM_ENC_START_IND:
            APP_SM_Encryption_Start_Callback( event );
            break;
        case RBLE_SM_TK_REQ_IND:
            APP_SM_TK_Request_CallBack( event );
            break;
        case RBLE_SM_LTK_REQ_IND:
            APP_SM_LTK_Request_CallBack( event );
            break;
        case RBLE_SM_IRK_REQ_IND:
            APP_SM_IRK_Request_CallBack( event );
            break;
        case RBLE_SM_CSRK_REQ_IND:
            break;
        case RBLE_SM_KEY_IND:
            APP_SM_Key_CallBack( event );
            break;
        case RBLE_SM_CHK_BD_ADDR_REQ:
            APP_SM_BDAddr_Check_Request_CallBack( event );
            break;
        case RBLE_SM_TIMEOUT_EVT:
            break;
        case RBLE_SM_EVENT_COMMAND_DISALLOWED_IND:
            break;
        default:
            break;
    }
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : SM Start Encryption Complete Event
 *
 *  @param      event   SM Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_SM_Encryption_Start_Callback( RBLE_SM_EVENT *event )
{
    (void) ((event));
    APP_Disp(APP_DISP_EVT, "Start Encryption");
    APP_Disp_Status(event->param.sec_start.status);

    return( true );
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : SM TK Request Event
 *
 *  @param      event   SM Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_SM_TK_Request_CallBack( RBLE_SM_EVENT *event )
{
    ConnectionIdx = event->param.tk_req.idx;

    /* Reply TK(Temporary Key) */
    APP_Set_RunCmd(SM_TK_REQ_RESP_CMD);
    APP_Disp(APP_DISP_EVT, "TK Request");

    return( true );
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : SM LTK Request Event
 *
 *  @param      event   SM Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_SM_LTK_Request_CallBack( RBLE_SM_EVENT *event )
{
    ConnectionIdx = event->param.ltk_req.idx;

    /* Reply LTK(Long Term Key) */
    APP_Set_RunCmd(SM_LTK_REQ_RESP_CMD);

    APP_Disp(APP_DISP_EVT, "LTK Request");

    return( true );
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : SM IRK Request Event
 *
 *  @param      event   SM Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_SM_IRK_Request_CallBack( RBLE_SM_EVENT *event )
{
    ConnectionIdx = event->param.irk_req.idx;

    /* Reply IRK(Identity Resolving Key) */
    APP_Set_RunCmd(SM_IRK_REQ_RESP_CMD);
    APP_Disp(APP_DISP_EVT, "IRK Request");

    return( true );
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : SM Key Indication Event
 *
 *  @param      event   SM Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_SM_Key_CallBack( RBLE_SM_EVENT *event )
{
    /* Store Encryption Key */
    if(RBLE_SMP_KDIST_ENCKEY       == event->param.key_ind.key_code)
    {
        RemoteKey.EncKey         = event->param.key_ind;
        RemoteKey.Key_Set_Flags |= (1 << APP_ENCKEY );
    }
    else if(RBLE_SMP_KDIST_IDKEY   == event->param.key_ind.key_code)
    {
        RemoteKey.IrKey          = event->param.key_ind;
        RemoteKey.Key_Set_Flags |= (1 << APP_IDKEY  );
    }
    else if(RBLE_SMP_KDIST_SIGNKEY == event->param.key_ind.key_code)
    {
        RemoteKey.SignKey        = event->param.key_ind;
        RemoteKey.Key_Set_Flags |= (1 << APP_SIGNKEY);
    }
    APP_Disp(APP_DISP_EVT, "Security Key Indicate");

    return( true );
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : SM Check BD Address Request Event
 *
 *  @param      event   SM Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_SM_BDAddr_Check_Request_CallBack( RBLE_SM_EVENT *event )
{
    ConnectionIdx = event->param.chk_bdaddr.idx;

    /* Check if Remote Device is already bonded */
    FoundFlg = APP_Compare_BDAddr(&BondedAddr, &event->param.chk_bdaddr.addr);

    /* Reply BD Address Check Result */
    APP_Set_RunCmd(SM_CHK_BD_ADDR_REQ_RESP_CMD);
    APP_Disp(APP_DISP_EVT, "Check BD Address");

    return( true );
}

/* ------------------------- Sample Custom Profile-------------------------------*/

/******************************************************************************************/
/**
 *  @brief      Event Handler : SCP Server Event
 *
 *  @param      event   SCP Server Event Parameters
 *
 *  @retval     None
 */
/******************************************************************************************/
static void APP_SCPS_CallBack( RBLE_SCPS_EVENT *event )
{
    switch( event->type){
        case RBLE_SCP_EVENT_SERVER_ENABLE_COMP:
            APP_SCPS_Enable_CallBack( event );
            break;
        case RBLE_SCP_EVENT_SERVER_DISABLE_COMP:
            break;
        case RBLE_SCP_EVENT_SERVER_ERROR_IND:
            break;
        case RBLE_SCP_EVENT_SERVER_SEND_NOTIFY_COMP:
            APP_SCPS_Send_Notify_CallBack( event );
            break;
        case RBLE_SCP_EVENT_SERVER_SEND_IND_COMP:
            APP_SCPS_Send_Indicate_CallBack( event );
            break;
        case RBLE_SCP_EVENT_SERVER_CHG_INDNTF_IND:
            APP_SCPS_Change_NtfInd_Config_CallBack( event );
            break;
        case RBLE_SCP_EVENT_SERVER_CHG_CHAR_IND:
            APP_SCPS_Change_Characteristic_CallBack( event );
            break;
        case RBLE_SCP_EVENT_SERVER_COMMAND_DISALLOWED_IND:
            break;
        default:
            break;
    }
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : SCP Server Enable Complete Event
 *
 *  @param      event   SCP Server Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_SCPS_Enable_CallBack( RBLE_SCPS_EVENT *event )
{
    (void) ((event));
    APP_Disp(APP_DISP_EVT, "SCP Server Enable");
    APP_Disp_Status(event->param.server_enable.status);

    return( true );
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : SCP Server Change Notification/Indication Configuration Event
 *
 *  @param      event   SCP Server Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_SCPS_Change_NtfInd_Config_CallBack( RBLE_SCPS_EVENT *event )
{
    /* Change Notification Configuration Event */
    if (event->param.cfg_indntf.char_code == RBLE_SCP_SCS_NTF_CFG)
    {
        if(event->param.cfg_indntf.cfg_val & RBLE_SCP_START_NTF)
        {
            Notify_On_count++;

            if( Notify_On_count == 1 )
            {
                /* Send Notification */
                APP_Set_RunCmd(SCP_Sensor_Send_Notify_CMD);

                /* Set timer for periodical Notification trigger */
                tx_timer_activate(&RBLE_App_Timer);
            }
        }
        else
        {
            if( Notify_On_count > 0 )
            {
                Notify_On_count--;
            }

            if( Notify_On_count == 0 )
            {
                /* Clear timer for Notification trigger */
                tx_timer_deactivate(&RBLE_App_Timer);
            }
        }
    }
    return( true );
}
/*
* This message is mainly for the LED Control
*/
void App_send_message( uint8_t CharValue)
{
    (void) ((CharValue));
#if(0)
    // BLE Application Thread should never block with TX_WAIT_FOREVER
    uint32_t sts = tx_queue_send(&g_app_receiver_queue, &CharValue, TX_NO_WAIT);
    if (sts != 0)
    {
        // FIXME: APP_Disp_Error("g_app_receiver_queue full");
    }
#endif
}
/******************************************************************************************/
/**
 *  @brief      Event Respond : SCP Server Change Characteristic Event
 *
 *  @param      event   SCP Server Event Parameters
 *
 *  @retval     TRUE if succeeded , FALSE if failed
 */
/******************************************************************************************/
static bool APP_SCPS_Change_Characteristic_CallBack( RBLE_SCPS_EVENT *event )
{
    /* Write Change Characteristic Event (Indication Command) */
    if(event->param.write_char.char_code == RBLE_SCP_SCS_CMD)
    {
 
        APP_Disp_RW((uint8_t)(event->param.write_char.value[0]));

        /* Send Indication */
        //APP_Disp(APP_DISP_EVT, "Send Indication");
        //APP_Set_RunCmd(SCP_Sensor_Send_Indicate_CMD);
        // App_send_message(CharValue);
    }
    return( TRUE );
}
/******************************************************************************************/
/**
 *  @brief      Event Respond : SCP Server Send Notification Complete Event
 *
 *  @param      event   SCP Server Event Parameters
 *
 *  @retval     true if succeeded , false if failed
 */
/******************************************************************************************/
static bool APP_SCPS_Send_Notify_CallBack( RBLE_SCPS_EVENT *event )
{
    (void) ((event));
    APP_Disp(APP_DISP_EVT, "Server Send Notification");
    APP_Disp_Status(event->param.send_notify.status);
    return( true );
}

/******************************************************************************************/
/**
 *  @brief      Event Respond : SCP Server Send Indication Complete Event
 *
 *  @param      event   SCP Server Event Parameters
 *
 *  @retval     TRUE if succeeded , FALSE if failed
 */
/******************************************************************************************/
static bool APP_SCPS_Send_Indicate_CallBack( RBLE_SCPS_EVENT *event )
{
    (void) ((event));
    APP_Disp(APP_DISP_EVT, "Server Send Indication");
    APP_Disp_Status(event->param.send_ind.status);
    return( true );
}

/* --------------------------- Utility -------------------------------------*/

uint32_t Reverse32( const uint32_t val )
{
   uint32_t retVal;
   char *ToConvert = ( char* ) & val;
   char *returnVal = ( char* ) & retVal;

   // swap the bytes into a temporary buffer
   returnVal[0] = ToConvert[3];
   returnVal[1] = ToConvert[2];
   returnVal[2] = ToConvert[1];
   returnVal[3] = ToConvert[0];

   return retVal;
}

void activity_notification(activity_data  *data)
{
    DataVal.DataEvent = ACTIVITY_VAL;
    memcpy(DataVal.DataValArr16, data, sizeof(activity_data));
    APP_Set_RunCmd(SCP_Sensor_Send_Notify_CMD);
}

void healthcare_notification(activity_data  *data)
{
    DataVal.DataEvent = HEALTHCARE_VAL;
    memcpy(DataVal.DataValArr16, data, sizeof(activity_data));

    APP_Set_RunCmd(SCP_Sensor_Send_Notify_CMD);
}

/******************************************************************************************/
/**
 *  @brief      Disconnection
 *
 *  @retval     None
 */
/******************************************************************************************/
void APP_Disconnect(void)
{
    /* Disconnection */
    APP_Set_RunCmd(GAP_DISCONNECT_CMD);
}

/******************************************************************************************/
/**
 *  @brief      Queueing Command
 *
 *  @param      cmd     Command Value , defined by RBLE_APP_CMD_NO_enum
 *
 *  @retval     None
 */
/******************************************************************************************/
static void APP_Set_RunCmd( uint32_t cmd )
{
    // This message send should not block because it is invoked by the APP_SCPS_Change_Characteristic_CallBack
    uint32_t sts = tx_queue_send(&g_RunCmd, &cmd, TX_NO_WAIT);
    if (sts != 0)
    {
        // FIXME: APP_Disp_Error("g_RunCmd full");
    }
}

/******************************************************************************************/
/**
 *  @brief      Compare BD Addresses
 *
 *  @param      a       BD Address
 *  @param      b       BD Address
 *
 *  @retval     true if same , false if different
 */
/******************************************************************************************/
static bool APP_Compare_BDAddr(RBLE_BD_ADDR* a, RBLE_BD_ADDR* b)
{
    uint8_t i;

    for(i = 0; i < RBLE_BD_ADDR_LEN; i++)
    {
        if(a->addr[i] != b->addr[i])
        {
            return false;
        }
    }
    return true;
}

/******************************************************************************************/
/**
 *  @brief      Get Random Number
 *
 *  @retval     Random Number
 */
/******************************************************************************************/
static int_t APP_Get_Random( void )
{
    return( rand() );
}

