/*
 ****************************************************************************************
 * DISCLAIMER
 ****************************************************************************************
 * This software and/or information (the "Material") is supplied by Renesas Electronics
 * Corporation. and is only intended for use with Renesas products. No other uses are authorized.
 * The Material is owned by Renesas Electronics Corporation and is protected under all applicable laws,
 * including copyright laws.
 * THIS MATERIAL IS PROVIDED "AS IS," AND RENESAS MAKES NO WARRANTIES REGARDING THIS MATERIAL,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
 * TO THE MAXIMUM EXTENT PERMITTED BY LAW, NEITHER RENESAS ELECTRONICS CORP. NOR ANY OF ITS
 * AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS MATERIAL, EVEN IF RENESAS OR ITS AFFILIATES
 * HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this Material
 * and to discontinue its availability
 *
 ****************************************************************************************
 * bma2x2_ext.h
 *
 *  Created on: Sep 23, 2015
 *      Author: alejandro
 ****************************************************************************************
 */

#ifndef SENSOR_BMA2X2_EXT_H_
#define SENSOR_BMA2X2_EXT_H_

#include <stdint.h>
#include "bma2x2.h"

#define BMA2X2_FIFO_DEPTH       32
#define BMA2X2_FIFO_FRAME_SIZE  (sizeof(struct bma2x2_accel_data))
#define BMA2X2_FIFO_SIZE        (BMA2X2_FIFO_FRAME_SIZE * BMA2X2_FIFO_DEPTH)

// NOTE:
// values defined below for LOW pass fileter do not correspond with datasheet
// but the empiric testing is showing that there seem to be a typo in the datasheet
// until proven otherwise they are patched right here
#ifdef BMA2x2_BW_31_25HZ
#   undef BMA2x2_BW_31_25HZ
#   define BMA2x2_BW_31_25HZ        0x09
#endif
#ifdef BMA2x2_BW_62_50HZ
#   undef BMA2x2_BW_62_50HZ
#   define BMA2x2_BW_62_50HZ        0x0A
#endif
#ifdef BMA2x2_BW_125HZ
#   undef BMA2x2_BW_125HZ
#   define BMA2x2_BW_125HZ          0x0B
#endif
#ifdef BMA2x2_BW_250HZ
#   undef BMA2x2_BW_250HZ
#   define BMA2x2_BW_250HZ          0x0C
#endif
#ifdef BMA2x2_BW_500HZ
#   undef BMA2x2_BW_500HZ
#   define BMA2x2_BW_500HZ          0x0D
#endif

typedef struct
{
    union
    {
        uint32_t  stat;
        struct
        {
            // INT_STATUS_0
            uint32_t  low_int   :  1;   // low-g interrupt status: ‘0’inactive, ‘1’ active
            uint32_t  high_int  :  1;   // high-g interrupt status: ‘0’inactive, ‘1’ active
            uint32_t  slope_int  :  1;  // slope interrupt status: ‘0’inactive, ‘1’ active
            uint32_t  slo_no_mot_int  :  1; // slow/no-motion interrupt status: ‘0’inactive, ‘1’ active
            uint32_t  d_tap_int  :  1;  // double tap interrupt status: ‘0’inactive, ‘1’ active
            uint32_t  s_tap_int  :  1;  // single tap interrupt status: ‘0’inactive, ‘1’ active
            uint32_t  orient_int  :  1; // orientation interrupt status: ‘0’inactive, ‘1’ active
            uint32_t  flat_int  :  1;   // flat interrupt status: ‘0’inactive, ‘1’ active
            // INT_STATUS_1
            uint32_t  reserved  :  5;   // reserved, write to ‘0’
            uint32_t  fifo_full_int  :  1; // FIFO full interrupt status: ‘0’inactive, ‘1’ active
            uint32_t  fifo_wm_int  :  1; // FIFO watermark interrupt status: ‘0’inactive, ‘1’ active
            uint32_t  data_int  :  1;   // data ready interrupt status: ‘0’inactive, ‘1’ active
            // INT_STATUS_2
            uint32_t  slope_first_x  :  1; // slope interrupt: ‘1’  triggered by, or ‘0’not triggered by x-axis
            uint32_t  slope_first_y  :  1; // slope interrupt: ‘1’  triggered by, or ‘0’not triggered by y-axis
            uint32_t  slope_first_z  :  1; // slope interrupt: ‘1’  triggered by, or ‘0’not triggered by z-axis
            uint32_t  slope_sign   :  1; // slope sign of slope tap triggering signal was ‘0’positive, or ‘1’ negative
            uint32_t  tap_first_x  :  1; // single/double tap interrupt: ‘1’  triggered by, or ‘0’not triggered by x-axis
            uint32_t  tap_first_y  :  1; // single/double tap interrupt: ‘1’  triggered by, or ‘0’not triggered by y-axis
            uint32_t  tap_first_z  :  1; // single/double tap interrupt: ‘1’  triggered by, or ‘0’not triggered by z-axis
            uint32_t  tap_sign  :  1;   // sign of single/double tap triggering signal was ‘0’positive, or ‘1’ negative
            // INT STATUS_3
            uint32_t  high_first_x  :  1; // high-g interrupt: ‘1’  triggered by, or ‘0’not triggered by x-axis
            uint32_t  high_first_y  :  1; // high-g interrupt: ‘1’  triggered by, or ‘0’not triggered by y-axis
            uint32_t  high_first_z  :  1; // high-g interrupt: ‘1’  triggered by, or ‘0’not triggered by z-axis
            uint32_t  high_sign  :  1;  // sign of acceleration signal that triggered high-g interrupt was ‘0’positive, ‘1’
                                        // negative
            uint32_t  orient_xy  :  2; // orientation value of x-y-plane:
                                                // ‘00’portrait upright; ‘01’portrait upside down;
                                                // ‘10’landscape left; ‘11’landscape right;
                                                // The flags always reflect the current orientation status, independent of the
                                                // setting of latch_int<3:0>. 1The flag is not updated as long as an orientation
                                                // blocking condition is active.
            uint32_t  orient_z  :  1; // Orientation value of z-axis: ´0´  upward looking, or ´1´  downward
                                                // looking. The flag always reflect the current orientation status, independent of
                                                // the setting of latch_int<3:0>. The flag is not updated as long as an
                                                // orientation blocking condition is active.
            uint32_t  flat  :  1; // device is in ‘1’  flat, or ‘0’ non flat position; only valid if (ACC 0x16) flat_en = ‘1’ ‘
        }bits;
    };
}bmx2x2_stat_t;

#endif /* SENSOR_BMA2X2_EXT_H_ */
