/*
 * x_print.h
 *
 *  Created on: Mar 23, 2016
 *      Author: alejandro
 */

#ifndef X_PRINT_H_
#define X_PRINT_H_

#include <stdio.h>
#include <stdarg.h>
#include <stdio.h>
#include <stdbool.h>

#ifdef CDC_WRITE_TIMEOUT_SEC
#   undef CDC_WRITE_TIMEOUT_SEC
#endif

#ifndef CDC_WRITE_TIMEOUT_SEC
#   define CDC_WRITE_TIMEOUT_SEC   10
#endif

extern void initialise_monitor_handles (void);

/**
 * @brief x_print_njtag initializes x_printf logger without JTAG support
 * @note ... THIS or x_print_init needs to be called before any other API
 *        can be used
 * @param none
 * @return none
 */
void x_print_njtag (void);

/***
 * @brief queues printf like formated string from application (thread) context
 *      NOTE: Do not call from ISR context
 * @param format, printf like format and parameters
 * @return none
 */
#define x_printf(s, ...)   x_printf_file_line(__FUNCTION__, __LINE__, s, __VA_ARGS__)

void x_printf_file_line(const char *filename, int line, const char *format, ...)
#ifdef __GNUC__
    __attribute__ ((format (printf, 3, 4)))
#endif
;

#define x_abort(s, ...)     do {                                                \
    x_printf_file_line(__FILE__, __LINE__, s, __VA_ARGS__);                     \
    x_abort_break();                                                            \
} while(1)

void x_abort_break(void);

/***
 * @brief flushes any pending x_printf calls out through the communication pathway
 * @return none
 */
ssp_err_t x_printf_flush(void);

/***
 * @brief queues printf like formated string from ISR context
 *      NOTE: Is the only allowed way to log from ISR context
 * @param format, printf like format and parameters
 * @return none
 */
void x_printf_isr(const char *format, ...);

/***
 * @brief Any user specific initialization required
 * @param none
 * @return none
 */
void x_printf_user_init (void);

#endif /* X_PRINT_H_ */
