package com.xaplos.hcsolution;

import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.widget.TextView;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;

public class BgmActivity extends AppCompatActivity implements BLEManager.BLEManagerNotifyListener {
    private final BLEManager mBle = BLEManager.getInstance();
    private TextView mGlucose;
    private TextView mStatus;

    // BgmStates
    private static final int INIT_PROCESS = 0;
    private static final int WAITING_FOR_STRIP = 1;
    private static final int STRIP_INSERTED = 2;
    private static final int BGM_MEASURE = 3;
    private static final int BGM_FINISHED = 4;
    private static final int BGM_FAILED = 5;

    private BroadcastReceiver receiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            mGlucose.setText("- mg/dL");
            mStatus.setText("-");
        }
    };

    private String reportBgmState(int state) {
        String result = "Idle";

        switch (state) {
            case WAITING_FOR_STRIP:
                result = "Insert Strip";
                break;
            case STRIP_INSERTED:
                result = "Waiting for sample";
                break;
            case BGM_MEASURE:
                result = "Measuring...";
                break;
            case BGM_FINISHED:
                result = "Complete";
                break;
            case BGM_FAILED:
                result = "Failed";
                break;
            case INIT_PROCESS:
            default:
                result = "Idle";
                break;
        }

        return result;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.bgm_activity);
        getSupportActionBar().hide();

        // register for disconnect event
        IntentFilter filter = new IntentFilter();
        filter.addAction("com.xaplos.BleDisconnect");
        registerReceiver(receiver, filter);

        mGlucose = (TextView)findViewById(R.id.text_view_glucose_value);
        mStatus = (TextView)findViewById(R.id.text_view_bgm_status_value);

        mBle.addNotifyListener(this);
    }

    @Override
    public void onNotification(Bundle notification) {
        int glucose = notification.getInt("Glucose");
        mGlucose.setText(String.valueOf(glucose) + " mg/dL");

        int status = notification.getInt("BgmStatus");
        mStatus.setText(String.valueOf(reportBgmState(status)));
    }

}
