package com.xaplos.hcsolution;

import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.widget.TextView;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;

public class BpmActivity extends AppCompatActivity implements BLEManager.BLEManagerNotifyListener {
    private final BLEManager mBle = BLEManager.getInstance();
    private TextView mSystolic;
    private TextView mDiastolic;
    private TextView mPulseRate;
    private TextView mStatus;

    // BpmStates
    private static final int INIT_PROCESS = 0;
    private static final int FIND_DIASTOLIC_PRESSURE = 1;
    private static final int FIND_BPM = 2;
    private static final int FIND_SYSTOLIC_PRESSURE = 3;
    private static final int MEASUREMENT_COMPLETE = 4;
    private static final int MEASUREMENT_FAILED = 5;

    private BroadcastReceiver receiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            mSystolic.setText("- mmHg");
            mDiastolic.setText("- mmHg");
            mPulseRate.setText("- bpm");
            mStatus.setText("-");
        }
    };


    private String reportBpmState(int state) {
        String result = "Idle";

        switch (state) {
            case FIND_DIASTOLIC_PRESSURE:
                result = "Diastolic";
                break;
            case FIND_BPM:
                result = "BPM";
                break;
            case FIND_SYSTOLIC_PRESSURE:
                result = "Systolic";
                break;
            case MEASUREMENT_COMPLETE:
                result = "Complete";
                break;
            case MEASUREMENT_FAILED:
                result = "Failed";
                break;
            case INIT_PROCESS:
            default:
                result = "Idle";
                break;
        }

        return result;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.bpm_activity);
        getSupportActionBar().hide();

        // register for disconnect event
        IntentFilter filter = new IntentFilter();
        filter.addAction("com.xaplos.BleDisconnect");
        registerReceiver(receiver, filter);

        mSystolic = (TextView)findViewById(R.id.text_view_systolic_value);
        mDiastolic = (TextView)findViewById(R.id.text_view_diastolic_value);
        mPulseRate = (TextView)findViewById(R.id.text_view_pulserate_value);
        mStatus = (TextView)findViewById(R.id.text_view_bpm_status_value);

        mBle.addNotifyListener(this);
    }

    @Override
    public void onNotification(Bundle notification) {
        int systolic = notification.getInt("Systolic");
        mSystolic.setText(String.valueOf(systolic) + " mmHg");

        int diastolic = notification.getInt("Diastolic");
        mDiastolic.setText(String.valueOf(diastolic) + " mmHg");

        int pulseRate = notification.getInt("PulseRate");
        mPulseRate.setText(String.valueOf(pulseRate) + " bpm");

        int status = notification.getInt("BpmStatus");
        mStatus.setText(String.valueOf(reportBpmState(status)));
    }
}
