package com.xaplos.hcsolution;

import android.app.LocalActivityManager;
import android.content.Context;
import android.content.Intent;
import android.content.res.Resources;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.ImageView;
import android.widget.TabHost;
import android.widget.TextView;

public class MainActivity extends AppCompatActivity {
    private LocalActivityManager mLocalActivityManager;
    private TabHost mTabHost;
    private BLEManager mBle = BLEManager.getInstance();
    private final String TAG = "MainActivity";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        Log.d(TAG, "onCreate");
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        mLocalActivityManager = new LocalActivityManager(this, false);
        mLocalActivityManager.dispatchCreate(savedInstanceState);
        setupTabs();

        mBle.setActivity(this);
        mBle.start();
    }

    @Override
    protected void onResume() {
        Log.d(TAG, "onResume");
        mLocalActivityManager.dispatchResume();
        super.onResume();
    }

    @Override
    protected void onPause() {
        Log.d(TAG, "onPause");
        mLocalActivityManager.dispatchPause(isFinishing());
        super.onPause();
    }

    @Override
    protected void onDestroy() {
        Log.d(TAG, "onDestroy");
        super.onDestroy();
    }

    @Override
    protected void onStart() {
        Log.d(TAG, "onStart");
        super.onStart();
    }

    @Override
    protected void onStop() {
        Log.d(TAG, "onStop");
        super.onStop();
    }

    @Override
    protected void onRestart() {
        Log.d(TAG, "onRestart");
        super.onRestart();
    }

    private static View prepareTabView(Context context, String label, int drawable) {
        View view = LayoutInflater.from(context).inflate(R.layout.tab_layout, null);

        ImageView image = (ImageView)view.findViewById(android.R.id.icon);
        image.setImageResource(drawable);

        TextView text = (TextView)view.findViewById(android.R.id.text1);
        text.setText(label);

        return view;
    }

    private void setupTabs() {
        mTabHost = (TabHost) findViewById(R.id.tabHost);
        mTabHost.setup(mLocalActivityManager);
        Resources res = getResources();

        View tabView;
        TabHost.TabSpec spec;

        spec = mTabHost.newTabSpec("Connect");
        spec.setContent(new Intent(this, ConnectActivity.class));
        tabView = prepareTabView(mTabHost.getContext(), "Go", R.drawable.icon_circle);
        spec.setIndicator(tabView);
        mTabHost.addTab(spec);

        spec = mTabHost.newTabSpec("Activity");
        spec.setContent(new Intent(this, ActivityActivity.class));
        tabView = prepareTabView(mTabHost.getContext(), "Active", R.drawable.icon_second);
        spec.setIndicator(tabView);
        mTabHost.addTab(spec);

        spec = mTabHost.newTabSpec("Sensors");
        spec.setContent(new Intent(this, SensorsActivity.class));
        tabView = prepareTabView(mTabHost.getContext(), "Sense", R.drawable.icon_circle);
        spec.setIndicator(tabView);
        mTabHost.addTab(spec);

        spec = mTabHost.newTabSpec("SpO2");
        spec.setContent(new Intent(this, SpO2Activity.class));
        tabView = prepareTabView(mTabHost.getContext(), "SpO2", R.drawable.icon_second);
        spec.setIndicator(tabView);
        mTabHost.addTab(spec);

        spec = mTabHost.newTabSpec("BPM");
        spec.setContent(new Intent(this, BpmActivity.class));
        tabView = prepareTabView(mTabHost.getContext(), "BPM", R.drawable.icon_circle);
        spec.setIndicator(tabView);
        mTabHost.addTab(spec);

        spec = mTabHost.newTabSpec("BGM");
        spec.setContent(new Intent(this, BgmActivity.class));
        tabView = prepareTabView(mTabHost.getContext(), "BGM", R.drawable.icon_second);
        spec.setIndicator(tabView);
        mTabHost.addTab(spec);

        /* to remove
        tabHost.getTabWidget().removeView(tabHost.getTabWidget().getChildTabViewAt(3));
        */
    }
}

