/*
 ****************************************************************************************
 * DISCLAIMER
 ****************************************************************************************
 * This software and/or information (the "Material") is supplied by Renesas Electronics
 * Corporation. and is only intended for use with Renesas products. No other uses are authorized.
 * The Material is owned by Renesas Electronics Corporation and is protected under all applicable laws,
 * including copyright laws.
 * THIS MATERIAL IS PROVIDED "AS IS," AND RENESAS MAKES NO WARRANTIES REGARDING THIS MATERIAL,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
 * TO THE MAXIMUM EXTENT PERMITTED BY LAW, NEITHER RENESAS ELECTRONICS CORP. NOR ANY OF ITS
 * AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS MATERIAL, EVEN IF RENESAS OR ITS AFFILIATES
 * HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this Material
 * and to discontinue its availability
 *
 ****************************************************************************************
 * d7seg.h
 *
 *  Created on: Dec 9, 2015
 *      Author: alejandro
 ****************************************************************************************
 */

#ifndef D7SEG_H_
#define D7SEG_H_

#include "../d7seg_config.h"
#include <stdint.h>

#define D7SEG_COUNT_PER_DIGIT   7
#define D7SEG_INVALID           -1

typedef struct
{
    uint8_t ascii;
    uint8_t code;
}d7seg_t;

typedef struct
{
    int seg[D7SEG_COUNT_PER_DIGIT]; // segments lines associated with seg A-G
    int dot;    // segment line associated with dot
}d7seg_lines_t;

typedef struct
{
    d7seg_lines_t pos[LCD_DIGITS];
}d7seg_disp_t;

#define D7SEG_DEF(N)        \
    .pos[N - 1] = {         \
       .seg = {             \
            D7SEG_A##N,     \
            D7SEG_B##N,     \
            D7SEG_C##N,     \
            D7SEG_D##N,     \
            D7SEG_E##N,     \
            D7SEG_F##N,     \
            D7SEG_G##N},    \
       .dot = D7SEG_DP##N,  \
    }

#define D7SEG_A         (1 << 0)
#define D7SEG_B         (1 << 1)
#define D7SEG_C         (1 << 2)
#define D7SEG_D         (1 << 3)
#define D7SEG_E         (1 << 4)
#define D7SEG_F         (1 << 5)
#define D7SEG_G         (1 << 6)
#define D7SEG_DP        (1 << 7)
#define D7SEG_OFF       0

/***
 * @brief d7seg_open does anything that might be necessary to use the display
 *
 * @param none
 *
 * @return none
 */
void d7seg_open (void);

/***
 * @brief d7seg_display_f displays a float in the screen
 *
 * @param f float to be displayed
 * @param pres precision
 */
void d7seg_display_f (float f, int pres);   // display float

/***
 * @brief d7seg_display_i displays an integer value
 *
 * @param val  value to be displayed
 *
 * @return none
 */
void d7seg_display_i (int val);

/***
 * @brief d7seg_display_str displays a string in the display
 *
 * @param str pointer to the null terminated string
 *
 * @return none
 */
void d7seg_display_str (char *str);

/**
 * Routines below need to be provided by the user as they are hardware specific
 */

/**
 * @brief hal_d7seg_write hardware specific routine to write a particular segment
 *
 * @param seg representation of a segment A0, B0 .... An-1, Bn-1 (n equal to the number of digits in the display)
 * @param v value to be written (0 or 1) ... could be other values in other applications
 *
 * @return none
 */
void hal_d7seg_write (int seg, int v);

/**
 * @brief  hal_d7seg_open provided by use to do any initialization if required
 */
int hal_d7seg_open (void);

#endif /* D7SEG_H_ */
