/*
 ****************************************************************************************
 * DISCLAIMER
 ****************************************************************************************
 * This software and/or information (the "Material") is supplied by Renesas Electronics
 * Corporation. and is only intended for use with Renesas products. No other uses are authorized.
 * The Material is owned by Renesas Electronics Corporation and is protected under all applicable laws,
 * including copyright laws.
 * THIS MATERIAL IS PROVIDED "AS IS," AND RENESAS MAKES NO WARRANTIES REGARDING THIS MATERIAL,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
 * TO THE MAXIMUM EXTENT PERMITTED BY LAW, NEITHER RENESAS ELECTRONICS CORP. NOR ANY OF ITS
 * AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS MATERIAL, EVEN IF RENESAS OR ITS AFFILIATES
 * HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this Material
 * and to discontinue its availability
 *
 ****************************************************************************************
*/
#include "adc_thread.h"
#include "adc.h"
#include "adc_process.h"
#include "main_thread.h"
#include "driver/led.h"

void adc_thread_entry(void);

static int handle_display_info (int *value);

/*
 * adc_context_t contains all necessary variables for adc_thread_entry
 */
typedef struct
{
    TX_EVENT_FLAGS_GROUP *event;
    TX_MUTEX *mutex;
    TX_QUEUE *queue;
    adc_sample_context_t  *adc_context;
    results_t results;
} adc_context_t;

adc_context_t adc_top_context =
{ .event = &adc_events,
  .mutex = &adc_mutex,
  .queue = &bg_queue,
  .adc_context = &adc_sample_context};

/* ADC Thread entry function controls all dealings with the adc and sample timer
 *
 */
void adc_thread_entry(void)
{
    int err;
    ULONG event;                                                                                    //Contains actual flags
    adc_context_t *c = &adc_top_context;
    results_t *r = &c->results;

    err = tx_event_flags_get (c->event, BOARD_INIT_EVENT,                                           //Wait for the board to be initialized
                        TX_OR, &event, TX_WAIT_FOREVER);

    while (err==0)
    {

        err = adc_wait_for_event (c->adc_context, &event, &r->bg_adc_val, &r->batt_value);          //Wait for an event dealing with the adc

        if (event & ADC_BATT_EVENT_FLAG)                                                            //Run if we are only sampling battery level right now (no strip inserted)
        {
            adc_process_batt (r->batt_value);
        }

        if (event & ADC_BG_BATT_EVENT_FLAG)                                                         //Run if we are sampling battery and strip level (strip inserted)
        {
            adc_process_bg_batt (r->batt_value, r->bg_adc_val,  &r->blood_glucose_value);
            handle_display_info (&r->blood_glucose_value);                                          //Send blood glucose level to display_thread_entry if it is valid
        }
    }
    led_white (STATUS_LED);                                                                         //Turn on LEDs if there is an error

    while (1)
    {
        tx_thread_sleep (1);
    }
}


static int handle_display_info (int *value)
{
    int err;
    adc_context_t *c = &adc_top_context;

    if (*value>0)                                                                                   //If blood glucose doesn't equal 0...
    {
        err = tx_queue_send(c->queue,value,TX_NO_WAIT);                                                   //Send blood glucose value to display_thread_entry
        *value=0;                                                                                   //Reset blood glucose value to prevent resending
    }

    return err;
}
