/*
  ****************************************************************************************
 * DISCLAIMER
 ****************************************************************************************
 * This software and/or information (the "Material") is supplied by Renesas Electronics
 * Corporation. and is only intended for use with Renesas products. No other uses are authorized.
 * The Material is owned by Renesas Electronics Corporation and is protected under all applicable laws,
 * including copyright laws.
 * THIS MATERIAL IS PROVIDED "AS IS," AND RENESAS MAKES NO WARRANTIES REGARDING THIS MATERIAL,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
 * TO THE MAXIMUM EXTENT PERMITTED BY LAW, NEITHER RENESAS ELECTRONICS CORP. NOR ANY OF ITS
 * AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS MATERIAL, EVEN IF RENESAS OR ITS AFFILIATES
 * HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this Material
 * and to discontinue its availability
 *
 ****************************************************************************************
*/
#include "display_thread.h"
#include "main_thread.h"
#include "events.h"
#include "config.h"
#include "util.h"
#include "display.h"
#include "driver/led.h"
#include "application_dispatcher_thread.h"
#include "common.h"

extern healthcare_data g_healthcare_data;

typedef enum
{
    D_IDLE, DISPLAY_RES, DISPLAY_WAIT, DISPLAY_FAILED,

} DISPLAY_STATES;

typedef enum
{
    STATE_ZERO, STATE_ONE, STATE_TWO, MAX_STATES,
} DISPLAY_STATE;

typedef struct
{
    TX_EVENT_FLAGS_GROUP *event;
    ULONG actual_flags;
    DISPLAY_STATES state;
    DISPLAY_STATE display_state;
    int res[3];
} display_context_t;

display_context_t display_context =
{ .event = &adc_events, .state = D_IDLE, .display_state = STATE_ZERO };

void display_thread_entry(void);

void switch_display_states (DISPLAY_STATE state);

static void handle_display_timeout(void);

static void reset_display_timer(void);

/* Display Thread entry function */
void display_thread_entry(void)
{

    UINT err;
    display_context_t *c = &display_context;

    err = tx_event_flags_get (c->event, BOARD_INIT_EVENT_DISP, TX_OR_CLEAR, &c->actual_flags, TX_WAIT_FOREVER);
    while (err == 0)
    {
        err = tx_event_flags_get (c->event, DISPLAY_MASK, TX_OR_CLEAR, &c->actual_flags, TX_WAIT_FOREVER);
        if (err)
        {
            tx_thread_sleep (1);
        }
        else
        {
            if (DISPLAY_RES_EVENT & c->actual_flags)
            {
                switch_display_states (DISPLAY_RES);
            }
            if (DISPLAY_WAIT_EVENT & c->actual_flags)
            {
                switch_display_states (DISPLAY_WAIT);
            }
            if (DISPLAY_FAILED_EVENT & c->actual_flags)
            {
                switch_display_states (DISPLAY_FAILED);
            }
            if (DISPLAY_TIMEOUT_EVENT & c->actual_flags)
            {
                handle_display_timeout ();
            }
        }
    }
    led_white (STATUS_LED);                                                                                             //Turn on LED if there is an error
    while (1)
    {
        tx_thread_sleep (1);
    }
}

void handle_display_timeout(void)
{
    display_context_t *c = &display_context;
    switch (c->state)
    {
        case D_IDLE:
            display_str ("   ");
            break;
        case DISPLAY_WAIT:
            display_str ("---");
            if( tx_queue_receive (&bp_queue, &c->res[0], TX_NO_WAIT) == TX_SUCCESS)
            {
                tx_queue_receive (&bp_queue, &c->res[1], TX_WAIT_FOREVER);
                tx_queue_receive (&bp_queue, &c->res[2], TX_WAIT_FOREVER);
                switch_display_states (DISPLAY_RES);
            }

        break;
        case DISPLAY_RES:
            // update data for BLE reporting
            tx_mutex_get(&g_data_mutex, TX_WAIT_FOREVER);
            g_healthcare_data.diastolic = (uint16_t)c->res[2];
            g_healthcare_data.systolic = (uint16_t)c->res[1];
            g_healthcare_data.pulse_rate = (uint16_t)c->res[0];
            tx_mutex_put(&g_data_mutex);

            if (c->display_state == STATE_ZERO)
                display_int (c->res[0]);
            else if (c->display_state == STATE_ONE)
                display_int (c->res[1]);
            else if (c->display_state == STATE_TWO)
                display_int (c->res[2]);

            c->display_state++;
            c->display_state = c->display_state % MAX_STATES;
        break;
        case DISPLAY_FAILED:
            c->display_state = (c->display_state == STATE_ONE) ? STATE_TWO : STATE_ONE;
            (c->display_state == STATE_ONE) ? display_str ("FA ") : display_str ("tA");
        break;
        default:
        break;
    }

}

void switch_display_states (DISPLAY_STATE state)
{
    display_context_t *c = &display_context;
    c->state = state;
    c->display_state = STATE_ZERO;
    reset_display_timer ();
}

static void reset_display_timer(void)
{
    display_context_t *c = &display_context;
    display_timer.p_api->close (display_timer.p_ctrl);
    display_timer.p_api->open (display_timer.p_ctrl, display_timer.p_cfg);
    tx_event_flags_set (c->event, DISPLAY_TIMEOUT_EVENT, TX_OR);
}

void display_timer_callback(timer_callback_args_t * p_args)
{
    UNUSED(p_args);

    display_context_t *c = &display_context;
    tx_event_flags_set (c->event, DISPLAY_TIMEOUT_EVENT, TX_OR);
}
