/*
 ****************************************************************************************
 * DISCLAIMER
 ****************************************************************************************
 * This software and/or information (the "Material") is supplied by Renesas Electronics
 * Corporation. and is only intended for use with Renesas products. No other uses are authorized.
 * The Material is owned by Renesas Electronics Corporation and is protected under all applicable laws,
 * including copyright laws.
 * THIS MATERIAL IS PROVIDED "AS IS," AND RENESAS MAKES NO WARRANTIES REGARDING THIS MATERIAL,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
 * TO THE MAXIMUM EXTENT PERMITTED BY LAW, NEITHER RENESAS ELECTRONICS CORP. NOR ANY OF ITS
 * AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS MATERIAL, EVEN IF RENESAS OR ITS AFFILIATES
 * HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this Material
 * and to discontinue its availability
 *
 ****************************************************************************************
 * led.h
 *
 *  Created on: Feb 3, 2016
 *      Author: alejandro
 ****************************************************************************************
 */

#ifndef DRIVER_LED_H_
#define DRIVER_LED_H_

typedef enum
{
    LED_ON,
    LED_OFF,
}led_state_t;

typedef enum
{
    LED_UNKNOWN,
    LED_FIRST,
    LED_1 = LED_FIRST,
    LED_2,
    LED_3,
    LED_4,
    LED_5,
    LED_6,
    LED_LAST = LED_6,
}led_t;

typedef enum
{
    STATUS_LED,
    POWER_LED,
    LED_PER_GROUP=3,
} led_group_t;

/***
 * @brief led_init, initializes all the LEDs to a known initial state
 *
 * @param none
 * @return none
 */
void led_init (void);

/***
 * @brief led_on, turns an LED ON
 *
 * @param led LED that is to be turned ON
 * @return none
 */
void led_on (led_t led);

/***
 * @brief led_on, turns an LED OFF
 *
 * @param led LED that is to be turned OFF
 * @return none
 */
void led_off (led_t led);

/***
 * @brief led_toggle, toggles an LED
 *
 * @param led LED that is to be TOGGLED
 * @return none
 */
void led_toggle (led_t led);

/***
 * @brief hal_led_init, initializes all the LEDs to a known initial state
 *
 * @param none
 * @return none
 */
void hal_led_init (void);

/***
 * @brief hal_led_state, defines the state of the given LED (@ hardware level)
 *
 * @param led what LED is been addressed
 * @param state LED_ON or LED_OFF
 * @return none
 */
void hal_led_state (led_t led, led_state_t state);

/***
 * @brief hal_led_state, retrieves the state of the given LED (@ hardware level)
 *
 * @param led what LED is been addressed
 * @return
 */
led_state_t hal_read_led_state (led_t led);

/**
 * @brief Utility function for shutting down all LEDs
 */
void led_all_off(void);

/**
 * led_red displays red led on chosen led
 */
void led_red(led_group_t led);

/**
 * led_red displays green led on chosen led
 */
void led_green(led_group_t led);

/**
 * led_red displays blue led on chosen led
 */
void led_blue(led_group_t led);

/**
 * led_red displays yellow led on chosen led
 */
void led_yellow(led_group_t led);

/**
 * led_white displays white led on chosen led
 */
void led_white (led_group_t led);

#endif /* DRIVER_LED_H_ */
