/*
 ****************************************************************************************
 * DISCLAIMER
 ****************************************************************************************
 * This software and/or information (the "Material") is supplied by Renesas Electronics
 * Corporation. and is only intended for use with Renesas products. No other uses are authorized.
 * The Material is owned by Renesas Electronics Corporation and is protected under all applicable laws,
 * including copyright laws.
 * THIS MATERIAL IS PROVIDED "AS IS," AND RENESAS MAKES NO WARRANTIES REGARDING THIS MATERIAL,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
 * TO THE MAXIMUM EXTENT PERMITTED BY LAW, NEITHER RENESAS ELECTRONICS CORP. NOR ANY OF ITS
 * AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS MATERIAL, EVEN IF RENESAS OR ITS AFFILIATES
 * HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this Material
 * and to discontinue its availability
 *
 ****************************************************************************************
 * pulse_adc_ssp.c
 *
 *  Created on: Jan 8, 2016
 *      Author: alejandro
 ****************************************************************************************
 */
#include "hal/adc_ssp.h"

/**
 * Synergy/SSP specific implementation and resources
 */
const pmcu_resource_t adc_mcu_res =
{
     .timer_arm = &sample_timer,
     .adc = &g_adc,
     .event = &adc_events,
};

int hal_adc_notify_init (const pmcu_resource_t *c)
{
    ssp_err_t err;
    SSP_PARAMETER_NOT_USED(c);
    err = SSP_SUCCESS;

    return err;
}

int hal_adc_notify_close (const pmcu_resource_t *c)
{
    ssp_err_t err;
    SSP_PARAMETER_NOT_USED(c);
    err = SSP_SUCCESS;

    return err;
}

int hal_adc_notify (const pmcu_resource_t *c, int event)
{
    int status;

    status = tx_event_flags_set (c->event, (ULONG)event, TX_OR);

    return status;
}

int hal_adc_wait_for_event (const pmcu_resource_t *c, ULONG *event)
{
    int status;
    ULONG actual_flags;

    status = tx_event_flags_get(c->event, ADC_EVENT_MASK, TX_OR_CLEAR,
                                 &actual_flags, TX_WAIT_FOREVER);


    if (TX_SUCCESS == status)
    {
        // return the flags
        *event = actual_flags;

    }

    return status;
}

int hal_adc_open (const pmcu_resource_t *c)
{
    ssp_err_t err;
    adc_ctrl_t *ctrl = c->adc->p_ctrl;
    adc_cfg_t const *cfg = c->adc->p_cfg;
    adc_api_t const *api = c->adc->p_api;

    adc_channel_cfg_t const *ch_cfg = c->adc->p_channel_cfg;

    err = api->open(ctrl, cfg);

    if (SSP_SUCCESS == err)
    {
        err = api->scanCfg (ctrl, ch_cfg);
    }


    return err;
}

int hal_adc_close (const pmcu_resource_t *c)
{
    ssp_err_t err;
    adc_ctrl_t *ctrl = c->adc->p_ctrl;
    adc_api_t const *api = c->adc->p_api;

    err = api->close(ctrl);

    return err;
}

int hal_sample_timer_open (const pmcu_resource_t *c)
{
    ssp_err_t err;
    timer_ctrl_t *ctrl = c->timer_arm->p_ctrl;
    timer_cfg_t const *cfg = c->timer_arm->p_cfg;
    timer_api_t const *api = c->timer_arm->p_api;

    // open the sample adc timer, it will auto start
    err = api->open (ctrl, cfg);

    return err;
}

int hal_sample_timer_close (const pmcu_resource_t *c)
{
    ssp_err_t err;
    timer_ctrl_t *ctrl = c->timer_arm->p_ctrl;
    timer_api_t const *api = c->timer_arm->p_api;

    err = api->close (ctrl);

    return err;
}

int hal_adc_scan_start (const pmcu_resource_t *c)
{
    ssp_err_t err;

    err = c->adc->p_api->scanStart(c->adc->p_ctrl);

    return err;
}

int hal_adc_sample_read (const pmcu_resource_t *c, adc_value_t *val)
{
    ssp_err_t err;
    adc_api_t const *api = c->adc->p_api;
    adc_ctrl_t *ctrl = c->adc->p_ctrl;
    adc_data_size_t value;

    err = api->read (ctrl, val->channel, &value);

    if (SSP_SUCCESS == err)
    {
        val->value = value;
    }
    else
    {
        // TODO:
        // handle error condition
    }

    return err;
}



/**
 * GPT Timer channel 2 ISR callback
 */
void sample_timer_callback (timer_callback_args_t * p_args)
{
    SSP_PARAMETER_NOT_USED(p_args);
    hal_adc_scan_start (&adc_mcu_res);
}


