/*
 ****************************************************************************************
 * DISCLAIMER
 ****************************************************************************************
 * This software and/or information (the "Material") is supplied by Renesas Electronics
 * Corporation. and is only intended for use with Renesas products. No other uses are authorized.
 * The Material is owned by Renesas Electronics Corporation and is protected under all applicable laws,
 * including copyright laws.
 * THIS MATERIAL IS PROVIDED "AS IS," AND RENESAS MAKES NO WARRANTIES REGARDING THIS MATERIAL,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
 * TO THE MAXIMUM EXTENT PERMITTED BY LAW, NEITHER RENESAS ELECTRONICS CORP. NOR ANY OF ITS
 * AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS MATERIAL, EVEN IF RENESAS OR ITS AFFILIATES
 * HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this Material
 * and to discontinue its availability
 *
 ****************************************************************************************
 * pulse_adc_ssp.h
 *
 *  Created on: Jan 8, 2016
 *      Author: alejandro
 ****************************************************************************************
 */

#ifndef HAL_ADC_SSP_H_
#define HAL_ADC_SSP_H_

#include "hal_data.h"
#include "tx_api.h"
#include "main_thread.h"
#include "events.h"
#include "demo_data.h"
/**
 * platform/MCU resources
 */

typedef struct
{
    int channel;
    int value;
}adc_value_t;


typedef struct
{
    const timer_instance_t *timer_arm;
    const adc_instance_t *adc;
    TX_EVENT_FLAGS_GROUP *event;
}pmcu_resource_t;

/****************
 * below are the HAL layer routines provided by user
 ****************/

/**
 * @brief hal_sample_adc_open hardware specific refer to sample_adc_open
 */
int hal_adc_open (const pmcu_resource_t *c);
/**
 * @brief hal_sample_adc_open hardware specific refer to sample_adc_open
 */
int hal_adc_close (const pmcu_resource_t *c);
/**
 * @brief hal_sample_timer_open hardware specific refer to sample_timer_open
 */
int hal_sample_timer_open (const pmcu_resource_t *c);
/**
 * @brief hal_sample_timer_open hardware specific refer to sample_timer_open
 */
int hal_sample_timer_close (const pmcu_resource_t *c);
/**
 * @brief hal_sample_settle_timer_open hardware specific refer to sample_settle_timer_open
 */
int hal_settle_timer_open (const pmcu_resource_t *c);
/**
 * @brief hal_sample_settle_timer_open hardware specific refer to sample_settle_timer_open
 */
int hal_settle_timer_close (const pmcu_resource_t *c);
/**
 * @brief hal_adc_settle_timer_start hardware specific refer to adc_settle_timer_start
 */
void hal_settle_timer_start (const pmcu_resource_t *c);
/**
 * @brief hal_adc_convert_start hardware specific refer to adc_convert_start
 */
int hal_adc_scan_start (const pmcu_resource_t *c);
/**
 * @brief hal_pulse_adc_sample_read hardware specific refer to pulse_adc_sample_read
 */
int hal_adc_sample_read (const pmcu_resource_t *c, adc_value_t *val);
/**
 * @brief hal_pulse_adc_notify_init hardware specific refer to pulse_adc_notify_init
 */
int hal_adc_notify_init (const pmcu_resource_t *c);
/**
 * @brief hal_pulse_adc_notify_init hardware specific refer to pulse_adc_notify_init
 */
int hal_adc_notify_close (const pmcu_resource_t *c);
/**
 * @brief hal_pulse_adc_notify hardware specific refer to pulse_adc_notify
 */
int hal_adc_notify (const pmcu_resource_t *c, int event);
/**
 * @brief hal_pulse_adc_wait_for_event hardware specific refer to pulse_adc_notify_init
 */
int hal_adc_wait_for_event (const pmcu_resource_t *c, ULONG *event);


#endif /* HAL_ADC_SSP_H_ */
