//
//  X1Services.h
//  BleDemo
//
//  Created by James Roth on 6/12/14.
//  Copyright (c) 2014 Xaplos. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CoreBluetooth/CBPeripheral.h>

// custom definitions for Renesas BLE Solution Kit demo
// service and characteristics
// Note, bytes coming from RL78 reversed from what's expected
// UUID for one-and-only service
//#define HC_DEMO_SERVICE               @"C0000000-0000-0000-0000-000000000000"
#define HC_DEMO_SERVICE                 @"00000000-0000-0000-0000-0000000000C0"
// UUID for reporting characteristic of all activity data (2 bytes each)
//#define HC_ACTIVITY_SENSOR            @"C0000000-0000-0000-0000-000000000001"
#define HC_ACTIVITY_SENSOR              @"01000000-0000-0000-0000-0000000000C0"
// UUID for reporting characteristic of all healthcare data (2 bytes each)
//#define HC_HEALTHCARE_SENSOR          @"C0000000-0000-0000-0000-000000000002"
#define HC_HEALTHCARE_SENSOR            @"02000000-0000-0000-0000-0000000000C0"

//
// The dictionaries are of name / value strings of the form: dict[@"heart rate"] = @"80.5"
// with at least one value.
//
@protocol NotificationDelgate <NSObject>
- (void)notification:(NSString *)identifier values:(NSDictionary *)value;
- (void)errorOccured:(NSString *)error;
@end

@protocol X1CharacteristicParser <NSObject>
- (NSDictionary *)characteristicDataToValues:(NSData *)data;
@end


@interface X1Services : NSObject <CBPeripheralDelegate>

@property (nonatomic, retain) CBPeripheral *peripheral;
@property (nonatomic, retain) CBUUID *serviceUUID;

// X1Streamable keyed with CBUUID of the characterisitc
@property (nonatomic, retain) NSDictionary *streamables;

@property (nonatomic, retain) CBCharacteristic *led1Characteristic;
@property (nonatomic, retain) CBCharacteristic *led2Characteristic;

- (id)initWithPeripheral:(CBPeripheral *)p;
- (void)discover;
- (void)discoverWithService:(NSString *)serviceUIDString;
- (void)setNotifications:(BOOL)enable;

@property (nonatomic, assign) id<NotificationDelgate> notificationDelegate;

@end
