//
//  SensorViewController.m
//  BLE Solution
//
//  Created by Mark F Rodriguez on 7/26/16.
//  Copyright © 2016 Mark F Rodriguez. All rights reserved.
//

#import "BloodViewController.h"

@interface BloodViewController ()

typedef enum
{
    INIT_PROCESS,
    FIND_DIASTOLIC_PRESSURE,
    FIND_BPM,
    FIND_SYSTOLIC_PRESSURE,
    MEASUREMENT_COMPLETE,
    MEASUREMENT_FAILED,
    BPM_MAX_STATES,
} bpm_state_t;

@end

@implementation BloodViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    // Tell notification center to inform on "HealthDataReceived" notifications
    // using the bleNotification: selector. By specifying object:nil, informing
    // the notification center we are not interested in who posted the notification.
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(bloodNotification:)
                                                 name:@"HealthDataReceived"
                                               object:nil];
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(bloodDisconnect:)
                                                 name:@"BleDisconnected"
                                               object:nil];
}

- (void) bloodNotification:(NSNotification *) notification
{
    if ([[notification name] isEqualToString:@"HealthDataReceived"]) {
        NSDictionary *values = [NSDictionary dictionaryWithDictionary:notification.userInfo];
        
        // systolic
        [self.systolicLabel setText:[values valueForKey:@"Systolic"]];
        
        // diastolic
        [self.diastolicLabel setText:[values valueForKey:@"Diastolic"]];
        
        // pulse rate
        [self.pulseRateLabel setText:[values valueForKey:@"PulseRate"]];
        
        // status
        switch ([[values valueForKey:@"BpmState"] intValue])
        {
            case FIND_DIASTOLIC_PRESSURE:
                [self.bpmStateLabel setText:@"Diastolic"];
                break;
            case FIND_BPM:
                [self.bpmStateLabel setText:@"BPM"];
                break;
            case FIND_SYSTOLIC_PRESSURE:
                [self.bpmStateLabel setText:@"Systolic"];
                break;
            case MEASUREMENT_COMPLETE:
                [self.bpmStateLabel setText:@"Complete"];
                break;
            case MEASUREMENT_FAILED:
                [self.bpmStateLabel setText:@"Failed"];
                break;
            case INIT_PROCESS:
            default:
                [self.bpmStateLabel setText:@"Idle"];
                break;
        }
    }
}

- (void) bloodDisconnect:(NSNotification *) notification
{
    if ([[notification name] isEqualToString:@"BleDisconnected"]) {
        // systolic
        [self.systolicLabel setText:@"-"];
        
        // diastolic
        [self.diastolicLabel setText:@"-"];
        
        // pulse rate
        [self.pulseRateLabel setText:@"-"];
        
        // status
        [self.bpmStateLabel setText:@"-"];
    }
}

- (void)dealloc {
    // Must remove observer; otherwise the Notification Center will
    // continue to try and send notification objects to the deallocated
    // object
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

@end
