/*
 ****************************************************************************************
 * DISCLAIMER
 ****************************************************************************************
 * This software and/or information (the "Material") is supplied by Renesas Electronics
 * Corporation. and is only intended for use with Renesas products. No other uses are authorized.
 * The Material is owned by Renesas Electronics Corporation and is protected under all applicable laws,
 * including copyright laws.
 * THIS MATERIAL IS PROVIDED "AS IS," AND RENESAS MAKES NO WARRANTIES REGARDING THIS MATERIAL,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
 * TO THE MAXIMUM EXTENT PERMITTED BY LAW, NEITHER RENESAS ELECTRONICS CORP. NOR ANY OF ITS
 * AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS MATERIAL, EVEN IF RENESAS OR ITS AFFILIATES
 * HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this Material
 * and to discontinue its availability
 *
 ****************************************************************************************
 * led_ssp.c
 *
 *  Created on: Feb 3, 2016
 *      Author: alejandro
 ****************************************************************************************
 */

#include "led.h"
#include "config.h"
#include "hal_data.h"

typedef struct
{
    ioport_port_pin_t pin;
    ioport_level_t on;
    ioport_level_t off;
    ioport_level_t def;
}led_info_t;

#define PIN_DEF(N)  {               \
		.pin = LED_##N##_PIN,       \
		.on = LED_##N##_ON_LEVEL,   \
		.off = LED_##N##_OFF_LEVEL, \
		.def = LED_##N##_DEFAULT,}

static led_info_t led_info[] =
{
     [LED_1] = PIN_DEF(1),
#if LED_COUNT > 1
     [LED_2] = PIN_DEF(2),
#endif
#if LED_COUNT > 2
     [LED_3] = PIN_DEF(3),
#endif
#if LED_COUNT > 3
     [LED_4] = PIN_DEF(4),
#endif
#if LED_COUNT > 4
     [LED_5] = PIN_DEF(5),
#endif
#if LED_COUNT > 5
     [LED_6] = PIN_DEF(6),
#endif
};

/***
 * @brief hal_led_state please refer to header for details
 */
void hal_led_init (void)
{
    ioport_api_t const *api = g_ioport.p_api;

    for (int i = LED_FIRST; i <= LED_LAST; i++)
    {
        // set them to a known desired default state
        api->pinWrite (led_info[i].pin, led_info[i].def);
    }
}

/***
 * @brief hal_led_state please refer to header for details
 */
void hal_led_state (led_t led, led_state_t state)
{
    ioport_api_t const *api = g_ioport.p_api;
    // set
    api->pinWrite (led_info[led].pin, LED_ON == state ? led_info[led].on : led_info[led].off);
}

/***
 * @brief hal_led_state please refer to header for details
 */
led_state_t hal_read_led_state (led_t led)
{
    led_state_t now;
    ioport_api_t const *api = g_ioport.p_api;
    ioport_level_t level;
    //
    api->pinRead (led_info[led].pin, &level);
    // translate from IO to the logic ON/OFF state
    now = level == led_info[led].on ? LED_ON : LED_OFF;

    return now;
}
