/*
 ****************************************************************************************
 * DISCLAIMER
 ****************************************************************************************
 * This software and/or information (the "Material") is supplied by Renesas Electronics
 * Corporation. and is only intended for use with Renesas products. No other uses are authorized.
 * The Material is owned by Renesas Electronics Corporation and is protected under all applicable laws,
 * including copyright laws.
 * THIS MATERIAL IS PROVIDED "AS IS," AND RENESAS MAKES NO WARRANTIES REGARDING THIS MATERIAL,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
 * TO THE MAXIMUM EXTENT PERMITTED BY LAW, NEITHER RENESAS ELECTRONICS CORP. NOR ANY OF ITS
 * AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS MATERIAL, EVEN IF RENESAS OR ITS AFFILIATES
 * HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this Material
 * and to discontinue its availability
 *
 ****************************************************************************************
 * led_pulse.c
 *
 *  Created on: Dec 16, 2015
 *      Author: alejandro
 ****************************************************************************************
 */

#include "led_pulse.h"

#define PULSE_STOP_ENABLED

/**
 * Forward declarations
 */
static void pulse_r_disable (void);
static void pulse_r_stop (void);
static void pulse_r_close (void);
static void pulse_ir_disable (void);
static void pulse_ir_stop(void);
static void pulse_ir_close (void);
static void pulse_X_begin (pulse_led_t led, uint32_t freq, int duty);

/**
 * @brief for detail, please lookup header file
 */
void pulse_r_begin_h (uint32_t freq_hz, int duty)
{
    pulse_X_begin (PULSE_LED_RED, freq_hz, duty);
}

/**
 * @brief for detail, please lookup header file
 */
void pulse_r_begin_kh (uint32_t freq_kh, int duty)
{
    pulse_r_begin_h (freq_kh * 1000, duty);
}

/**
 * @brief for detail, please lookup header file
 */
void pulse_ir_begin_h (uint32_t freq_hz, int duty)
{
    pulse_X_begin (PULSE_LED_IRED, freq_hz, duty);
}

/**
 * @brief for detail, please lookup header file
 */
void pulse_ir_begin_kh (uint32_t freq_kh, int duty)
{
    pulse_ir_begin_h (freq_kh * 1000, duty);
}

/**
 * @brief for detail, please lookup header file
 */
void pulse_r_end (void)
{
    //
    pulse_r_disable ();
#ifdef PULSE_STOP_ENABLED
    pulse_r_stop ();
    pulse_r_close ();
#endif
}

/**
 * @brief for detail, please lookup header file
 */
void pulse_ir_end (void)
{
    //
    pulse_ir_disable ();
#ifdef PULSE_STOP_ENABLED
    pulse_ir_stop ();
    pulse_ir_close ();
#endif
}

/**
 * Helper routines below
 */
static void pulse_r_drive (bool enable)
{
    hal_pulse_X_drive (PULSE_LED_RED, enable);
}

static void pulse_ir_drive (bool enable)
{
    hal_pulse_X_drive (PULSE_LED_IRED, enable);
}

static void pulse_r_enable (void)
{
    pulse_r_drive (true);
}

static void pulse_ir_enable (void)
{
    pulse_ir_drive (true);
}

static void pulse_r_disable (void)
{
    pulse_r_drive (false);
}

static void pulse_ir_disable (void)
{
    pulse_ir_drive (false);
}

static void pulse_r_open (void)
{
    hal_pulse_X_open (PULSE_LED_RED);
}

static void pulse_r_close (void)
{
    hal_pulse_X_close (PULSE_LED_RED);
}

static void pulse_ir_close (void)
{
    hal_pulse_X_close (PULSE_LED_IRED);
}

static void pulse_ir_open (void)
{
    hal_pulse_X_open (PULSE_LED_IRED);
}

static void pulse_r_stop(void)
{
    hal_pulse_X_stop (PULSE_LED_RED);
}

static void pulse_ir_stop(void)
{
    hal_pulse_X_stop (PULSE_LED_IRED);
}

static void pulse_r_modify (uint32_t freq, int duty)
{
    hal_pulse_X_modify (PULSE_LED_RED, freq, duty);
}

static void pulse_ir_modify (uint32_t freq, int duty)
{
    hal_pulse_X_modify (PULSE_LED_IRED, freq, duty);
}

static void pulse_X_begin (pulse_led_t led, uint32_t freq, int duty)
{
    switch (led)
    {
        case PULSE_LED_RED:
            pulse_r_open ();
            //
            pulse_r_enable ();
            //
            pulse_r_modify (freq, duty);
            break;

        case PULSE_LED_IRED:
            pulse_ir_open ();
            //
            pulse_ir_enable ();
            //
            pulse_ir_modify (freq, duty);
            break;

        default:
            break;
    }
}
