/*
 ****************************************************************************************
 * DISCLAIMER
 ****************************************************************************************
 * This software and/or information (the "Material") is supplied by Renesas Electronics
 * Corporation. and is only intended for use with Renesas products. No other uses are authorized.
 * The Material is owned by Renesas Electronics Corporation and is protected under all applicable laws,
 * including copyright laws.
 * THIS MATERIAL IS PROVIDED "AS IS," AND RENESAS MAKES NO WARRANTIES REGARDING THIS MATERIAL,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
 * TO THE MAXIMUM EXTENT PERMITTED BY LAW, NEITHER RENESAS ELECTRONICS CORP. NOR ANY OF ITS
 * AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS MATERIAL, EVEN IF RENESAS OR ITS AFFILIATES
 * HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this Material
 * and to discontinue its availability
 *
 ****************************************************************************************
 * led_pulse.h
 *
 *  Created on: Dec 16, 2015
 *      Author: alejandro
 ****************************************************************************************
 */

#ifndef LED_PULSE_H_
#define LED_PULSE_H_

#include <stdint.h>
#include <stdbool.h>

#define LED_SAMPLE_RATE 100

typedef enum
{
    PULSE_LED_RED,
    PULSE_LED_IRED,
    PULSE_LED_COUNT,
}pulse_led_t;

/***
 * @brief pulse_r_begin_h starts the RED led pulse generation
 *
 * @param freq_h frequency in Hz at which generate the pulse
 * @param duty duty cycle in percent (1-99%)
 *
 * @return none
 */
void pulse_r_begin_h (uint32_t freq_hz, int duty);

/***
 * @brief pulse_r_begin_kh starts the RED led pulse generation
 *
 * @param freq_kh frequency in KHz at which generate the pulse
 * @param duty duty cycle in percent (1-99%)
 *
 * @return none
 */
void pulse_r_begin_kh (uint32_t freq_kh, int duty);

/***
 * @brief pulse_ir_begin_h starts the IR led pulse generation
 *
 * @param freq_h frequency in Hz at which generate the pulse
 * @param duty duty cycle in percent (1-99%)
 *
 * @return none
 */
void pulse_ir_begin_h (uint32_t freq_hz, int duty);

/***
 * @brief pulse_ir_begin_kh starts the IR led pulse generation
 *
 * @param freq_kh frequency in KHz at which generate the pulse
 * @param duty duty cycle in percent (1-99%)
 *
 * @return none
 */
void pulse_ir_begin_kh (uint32_t freq_kh, int duty);

/***
 * @brief pulse_ir_end finalizes the IR pulse generation
 *
 * @param none
 *
 * @return none
 */
void pulse_r_end (void);

/***
 * @brief pulse_ir_end finalizes the IR pulse generation
 *
 * @param none
 *
 * @return none
 */
void pulse_ir_end (void);

/**
 * @brief hal_pulse_X_drive setup IO related to allowing (gating) the PULSE driving
 * this is hardware specific and must be provided by user
 *
 * @param led PULSE_LED_RED or PULSE_LED_IRED
 * @param enable true to enable false to disable
 *
 * @return none
 */
void hal_pulse_X_drive (pulse_led_t led, bool enable);

/**
 * @brief hal_pulse_X_open initializes PWM related hardware for a given LED
 * this is hardware specific and must be provided by user
 *
 * @param led PULSE_LED_RED or PULSE_LED_IRED
 *
 * @return none
 */
void hal_pulse_X_open (pulse_led_t led);

/**
 * @brief hal_pulse_X_stop stops PWM generation for a given LED
 * this is hardware specific and must be provided by user
 *
 * @param led PULSE_LED_RED or PULSE_LED_IRED
 *
 * @return none
 */
void hal_pulse_X_stop(pulse_led_t led);

/***
 * @brief hal_pulse_X_modify modifies frequency and duty cycle of a given LED
 *
 * @param led PULSE_LED_RED or PULSE_LED_IRED
 * @param freq frequency in Hz at which generate the pulse
 * @param duty duty cycle in percent (1-99%)
 *
 * @return none
 */
void hal_pulse_X_modify(pulse_led_t led, uint32_t freq, int duty);

/**
 * @brief hal_pulse_X_close closes peripheral
 * this is hardware specific and must be provided by user
 *
 * @param led PULSE_LED_RED or PULSE_LED_IRED
 *
 * @return none
 */
void hal_pulse_X_close (pulse_led_t led);

#endif /* LED_PULSE_H_ */
