/*
 ****************************************************************************************
 * DISCLAIMER
 ****************************************************************************************
 * This software and/or information (the "Material") is supplied by Renesas Electronics
 * Corporation. and is only intended for use with Renesas products. No other uses are authorized.
 * The Material is owned by Renesas Electronics Corporation and is protected under all applicable laws,
 * including copyright laws.
 * THIS MATERIAL IS PROVIDED "AS IS," AND RENESAS MAKES NO WARRANTIES REGARDING THIS MATERIAL,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
 * TO THE MAXIMUM EXTENT PERMITTED BY LAW, NEITHER RENESAS ELECTRONICS CORP. NOR ANY OF ITS
 * AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS MATERIAL, EVEN IF RENESAS OR ITS AFFILIATES
 * HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this Material
 * and to discontinue its availability
 *
 ****************************************************************************************
 * pulse_adc.c
 *
 *  Created on: Jan 8, 2016
 *      Author: alejandro
 ****************************************************************************************
 */

#include "util.h"
#include "pulse_adc.h"
#include "pulse_bias.h"

static void pulse_adc_feedback_track (pulse_adc_sample_context_t *c);

pulse_adc_sample_context_t  pulse_adc_sample_context =
{
     .res = &pulse_adc_mcu_res,
    .sample[PULSE_LED_RED].channel = ADC_REG_CHANNEL_3,
    .sample[PULSE_LED_IRED].channel = ADC_REG_CHANNEL_3,
    .feedback[ADC_TRANS_AMP_AOUT].channel = ADC_REG_CHANNEL_2,
    .feedback[ADC_TRANS_AMP_NEG].channel = ADC_REG_CHANNEL_1,
    .feedback[ADC_TRANS_AMP_POS].channel = ADC_REG_CHANNEL_0,
    .feedback[ADC_GAIN_AMP_OUT].channel = ADC_REG_CHANNEL_7,
    .feedback[ADC_GAIN_AMP_POS].channel = ADC_REG_CHANNEL_5,
    .feedback[ADC_GAIN_AMP_NEG].channel = ADC_REG_CHANNEL_6,
};

/**
 * @brief pulse_adc_init, refer to header file for details
 */
int pulse_adc_notify_init (const pmcu_resource_t *c)
{
    int err;

    err = hal_pulse_adc_notify_init (c);

    return err;
}

/**
 * @brief pulse_adc_notify, refer to header file for details
 */
int pulse_adc_notify (const pmcu_resource_t *c, int event)
{
    int err;

    err = hal_pulse_adc_notify (c, event);

    return err;
}

int pulse_adc_wait_for_event (int *event, int *red, int *ired)
{
    int err;
    int value[PULSE_LED_COUNT];

    err = hal_pulse_adc_wait_for_event (&pulse_adc_sample_context, event, value);
    //
    *red = value[PULSE_LED_RED];
    *ired = value[PULSE_LED_IRED];

    return err;
}

/**
 * @brief pulse_adc_init, refer to header file for details
 */
int pulse_adc_init (void)
{
    int err;
    pulse_adc_sample_context_t *c = &pulse_adc_sample_context;

    // init
    c->step = PULSE_ADC_SAMPLE_START;

    err = pulse_adc_notify_init (c->res);

    if (0 == err)
    {
        err = sample_timer_open (c->res);
    }
    //
    if (0 == err)
    {
        err = sample_settle_timer_open (c->res);
    }

    if (0 == err)
    {
        err = sample_adc_open (c->res);
    }

    return err;
}

/**
 * @brief sample_adc_open, refer to header file for details
 */
int sample_adc_open (const pmcu_resource_t *c)
{
    int err;

    err = hal_sample_adc_open (c);

    return err;
}

/**
 * @brief sample_timer_open, refer to header file for details
 */
int sample_timer_open (const pmcu_resource_t *c)
{
    int err;

    err = hal_sample_timer_open (c);

    return err;
}

/**
 * @brief sample_settle_timer_open, refer to header file for details
 */
int sample_settle_timer_open (const pmcu_resource_t *c)
{
    int err;

    err = hal_sample_settle_timer_open (c);

    return err;
}

/**
 * @brief adc_convert_start, refer to header file for details
 */
void adc_convert_start (float v, const pmcu_resource_t *c)
{
//    if (v >= 0)
//    {
//        pulse_bias_v (v);
//    }

    hal_adc_convert_start (c);
}

/**
 * @brief adc_settle_timer_start, refer to header file for details
 */
void adc_settle_timer_start (const pmcu_resource_t *c)
{
    hal_adc_settle_timer_start (c);
}

/**
 * @brief adc_idle_timer_start, refer to header file for details
 */
void adc_idle_timer_start (const pmcu_resource_t *c)
{
    hal_adc_idle_timer_start (c);
}

/**
 * @brief pulse_adc_sample_read, refer to header file for details
 */
int pulse_adc_sample_read (pulse_adc_sample_context_t *c, pulse_adc_sample_led_t *sample)
{
    int err;

    err =  hal_pulse_adc_sample_read (c, sample);

    return err;
}

/**
 * @brief pulse_adc_sample_arm_handle, refer to header file for details
 */
void pulse_adc_sample_arm_handle (pulse_adc_sample_context_t *c)
{
    switch (c->step)
    {
        case PULSE_ADC_SAMPLE_START:
            // set up the PWM R and let it settle
            pulse_r_begin_h (R_LED_FREQ_HZ, R_LED_DUTY_PERCENT);
            // start the settling time
            adc_settle_timer_start (c->res);
            // now we wait for some settling time
            c->step = PULSE_ADC_R_SETTLE;
            break;

        case PULSE_ADC_R_SETTLE:
            // prepare to start the Infra RED led OFFSET setup
            // now we need to sample the PULSE_ADC LINE
            adc_convert_start (PULSE_IR_OFFSET_V, c->res);
            // adc conversion has started
            c->step = PULSE_ADC_R_SAMPLE;
            // adc will convert ... and after notifying will call next state
            break;

        case PULSE_ADC_R_SAMPLE:
            // stop the LED
            pulse_r_end ();
            // ADC has been done and notified ... now we need to add and idle time
            adc_idle_timer_start (c->res);
            //
            c->step = PULSE_ADC_IDLE;
            break;

        case PULSE_ADC_IDLE:
            // idle time has lapse ... need to setup the IR signal
            // set up the PWM IR and let it settle
            pulse_ir_begin_h (IR_LED_FREQ_HZ, IR_LED_DUTY_PERCENT);
            // start the settling time
            adc_settle_timer_start (c->res);
            // now we wait for some settling time
            c->step = PULSE_ADC_IR_SETTLE;
            break;

        case PULSE_ADC_IR_SETTLE:
            // prepare to start the RED led OFFSET setup
            // now we need to sample the PULSE_ADC LINE
            adc_convert_start (PULSE_R_OFFSET_V, c->res);
            // adc conversion has started
            c->step = PULSE_ADC_IR_SAMPLE;
            break;

        case PULSE_ADC_IR_SAMPLE:
            // stop the LED
            pulse_ir_end ();
            // this is the last STEP
            // sample got collected already by the ADC ISR END callback
            // all we need is to wait for the next cycle to start
            c->step = PULSE_ADC_SAMPLE_START;
            break;

        case PULSE_ADC_MAX_STEPS:
            // here just to shut up the compiler
            break;
    }
}

/**
 * @brief pulse_adc_sample_start_start, refer to header file for details
 */
void pulse_adc_sample_start_start (pulse_adc_sample_context_t *c)
{
    pulse_adc_sample_arm_handle (c);
}

/**
 * @brief pulse_adc_sample_handle, refer to header file for details
 */
void pulse_adc_sample_handle (pulse_adc_sample_context_t *c)
{
    pulse_adc_sample_led_t *sample = NULL;
    int err = SSP_ERR_UNSUPPORTED;
    int event = PULSE_EVENT_NONE;

    pulse_adc_feedback_track (c);

    // at this point something got sampled
    switch (c->step)
    {
        case PULSE_ADC_R_SAMPLE:
            sample = &c->sample[PULSE_LED_RED];
            event = PULSE_R_EVENT_FLAG;
            break;

        case PULSE_ADC_IR_SAMPLE:
            sample = &c->sample[PULSE_LED_IRED];
            event = PULSE_IR_EVENT_FLAG;
            break;

        default:
            __asm__ ("nop");
            break;
    }

    if (NULL == sample)
    {
        // this should not execute
        // TODO:
        // handle error
    }
    else
    {
        err = pulse_adc_sample_read (c, sample);

        if (0 == err)
        {
            // TODO:
            // notify of this value acquired
            err = pulse_adc_notify (c->res, event);
        }
    }

    if (0 == err)
    {
        // do anything else required
        pulse_adc_sample_arm_handle (c);
    }
    else
    {
        // NOTE:
        // handle error condition
    }
}

#define ADC_RES (1 << 14)

float pulse_adc_percent (int adc)
{
    float temp;

    temp = (float)adc;
    temp *= 100;
    temp /= ADC_RES;

    return temp;
}

static void pulse_adc_feedback_track (pulse_adc_sample_context_t *c)
{
    for (int i = 0; i < ADC_FEEDBACK_COUNT; i++)
    {
        pulse_adc_sample_read (c, &c->feedback[i]);
    }
}
