/*
 ****************************************************************************************
 * DISCLAIMER
 ****************************************************************************************
 * This software and/or information (the "Material") is supplied by Renesas Electronics
 * Corporation. and is only intended for use with Renesas products. No other uses are authorized.
 * The Material is owned by Renesas Electronics Corporation and is protected under all applicable laws,
 * including copyright laws.
 * THIS MATERIAL IS PROVIDED "AS IS," AND RENESAS MAKES NO WARRANTIES REGARDING THIS MATERIAL,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
 * TO THE MAXIMUM EXTENT PERMITTED BY LAW, NEITHER RENESAS ELECTRONICS CORP. NOR ANY OF ITS
 * AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS MATERIAL, EVEN IF RENESAS OR ITS AFFILIATES
 * HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this Material
 * and to discontinue its availability
 *
 ****************************************************************************************
 * pulse_adc_process.c
 *
 *  Created on: Jan 8, 2016
 *      Author: alejandro
 ****************************************************************************************
 */

#include "led.h"
#include "events.h"
#include "config.h"
#include "pulse_adc.h"
#include "pulse_bias.h"
#include "pulse_adc_process.h"
#include "common.h"
#include "display.h"
#include "led_pulse.h"
#include "application_dispatcher_thread.h"

#define HR_INVALID_TIME     1000    // 10 secone based on 10ms tick rate


#define KUP 15    // 0.01
#define KDOWN 200 // 0.2
#define MAX_DEL_HR 20 // BPM
#define RED_KAVG 200 // 0.2
#define IR_KAVG 200 // 0.2


#define MIN_VALUE 0
#define MAX_VALUE 16383 // 14 bit max
#define MAX_COUNTER_SINCE_LAST_TRIGGER 20
#define MAX_COUNT_UPDATE 150

#define UPDATE_OFFSETS  0 // This define is to allow the DAC offset feedback to operate.

#define MAX_DEL_COUNT 1000

#define MIN_PULSE_AMP 745 // 0.15V with 14 bit with 3.3V Ref
#define CONST_60_DIV_TSAM 6000 // 60/Tsam :used to calculate HR
#define HR_NOT_AVAILABLE 0 // value to use when HR not valid
#define MAX_DELTA_HR 10

#define VOFF_TARGET 8192 // 1.65V with 14 bit ADC with 3.3 Vref
#define MAX_OFFSET_CHANGE 200 //2482  // 0.5v with 14 bit ADC with 3.3 Vref
#define MIN_OFFSET_CHANGE -200 // -2482 // -620 // -0.5v with 14 bit ADC with 3.3 Vref
#define MAX_OFFSET 10674 // 1.65v + 0.5v
#define MIN_OFFSET 200 //5710 // 1.65v - 0.5v


#define K_AVG_HR  100 // 0.1 based on scale of 1000
#define K_AVG_MAX_MIN 100 // 0.1 based on scale of 1000

typedef enum {IDLE, READ_IR_CONFIG_RED, READ_RED_CONFIG_IR_OBTAIN_ALL_RESULT} PULSE_STATES;

extern healthcare_data g_healthcare_data;

static uint16_t g_RED_Offset = OFFSET_INIT; // 1.2 v
static uint16_t g_IR_Offset = OFFSET_INIT; // 1.2 v

static uint16_t RED_Reading = 0;
static uint16_t IR_Reading = 0;

static uint16_t Vout1_Track = 0, Vout2_Track = 0;

static float O2_Calc_Poly_Array[3] = {106.3f,-8.824f, 0.0f}; //{114,-20.139, -3.4722} scaled by 1000;
float NormRatio = 0.0f;static uint16_t Prev_O2_Saturation = 0;

int Set_Red_Enable_State ( int Red_Enable );
int Set_IR_Enable_State ( int IR_Enable );


/*****************************************************************************************/
int Track_Run_Max_Min (uint16_t Vin, int Kup, int Kdown, bool Init, uint16_t *Vout, uint16_t *Vout2)
{   // Function should only be called from one location
    // Track_Run_Min_Max.vi
    static int Prev_Output = 0;
    static int Prev_Output_2 = 0;
    int Sel_Kavg = 0;
    int Sel_Kavg_2 = 0;

    if (Init)
    { // Set both outputs to input Vin
      *Vout = Vin;
      *Vout2 = Vin;
    }
    else
    {
      if ( Vin > Prev_Output )
      {
          Sel_Kavg = Kup;
      }
      else
      {
          Sel_Kavg = Kdown;
      }
      if ( !(Vin > Prev_Output_2) )
      {
          Sel_Kavg_2 = Kup;
      }
      else
      {
          Sel_Kavg_2 = Kdown;
      }
      *Vout  = (uint16_t)(( Sel_Kavg * Vin - (Sel_Kavg - 1000) * Prev_Output ) / 1000);
      *Vout2 = (uint16_t)(( Sel_Kavg_2 * Vin - (Sel_Kavg_2 - 1000) * Prev_Output_2 ) / 1000);
    }
    Prev_Output = *Vout;
    Prev_Output_2 = *Vout2;
    return 0;
}

/***********************************************************************************************/
bool HR3 ( int Vin, int compare, int Input_2, uint16_t *HR_out, uint16_t *Max1, uint16_t *Min1, uint16_t *Max2, uint16_t *Min2 )
{ // HR3.vi
  static int Counter_Since_Last_Trigger = 0;
  static bool PrevComparison = false;
  static int Step_Count = 0;
  bool Valid = false;
  static int Acc_Ctr = 0;
  static int Last_acc_Ctr = 0;
  static int cycle_Max_1 = MIN_VALUE;
  static int hold_Max_1  = MIN_VALUE;
  static int cycle_Min_1 = MAX_VALUE;
  static int hold_Min_1  = MAX_VALUE;
  static int cycle_Max_2 = MIN_VALUE;
  static int hold_Max_2  = MIN_VALUE;
  static int cycle_Min_2 = MAX_VALUE;
  static int hold_Min_2  = MAX_VALUE;
  static int Last_Valid_HR = 0;

  bool tmpComp = false;

  tmpComp = (Vin < compare);
  if ( (!PrevComparison && (Counter_Since_Last_Trigger > MAX_COUNTER_SINCE_LAST_TRIGGER) && tmpComp) || (Counter_Since_Last_Trigger > MAX_COUNT_UPDATE) )
  { // Trigger
    Counter_Since_Last_Trigger = 0;
    if ( MAX_DEL_COUNT > abs (Acc_Ctr - Last_acc_Ctr) )
    {
      Step_Count++;
      Valid = true;
      Last_acc_Ctr = Acc_Ctr;
    }
    Acc_Ctr = 0;

    hold_Max_1  = cycle_Max_1;
    cycle_Max_1 = MIN_VALUE;

    hold_Min_1  = cycle_Min_1;
    cycle_Min_1 = MAX_VALUE;

    hold_Max_2  = cycle_Max_2;
    cycle_Max_2 = MIN_VALUE;

    hold_Min_2  = cycle_Min_2;
    cycle_Min_2 = MAX_VALUE;
  }
  else
  {
    Counter_Since_Last_Trigger++;
    Acc_Ctr++;
    if ( Vin > cycle_Max_1 )
    {
      cycle_Max_1 = Vin;
    }
    if ( Vin < cycle_Min_1 )
    {
      cycle_Min_1 = Vin;
    }
    if ( Input_2 > cycle_Max_2 )
    {
      cycle_Max_2 = Input_2;
    }
    if ( Input_2 < cycle_Min_2 )
    {
      cycle_Min_2 = Input_2;
    }
  }
  PrevComparison = tmpComp;

  Valid = Valid & ((hold_Max_1 - hold_Min_1) > MIN_PULSE_AMP);
  if (Valid)
  {
      *HR_out = (uint16_t)(CONST_60_DIV_TSAM / Last_acc_Ctr);
      Last_Valid_HR = *HR_out;
  }
  else
  {
      *HR_out = (uint16_t)Last_Valid_HR;
  }
  *Max1 = (uint16_t)hold_Max_1;
  *Min1 = (uint16_t)hold_Min_1;
  *Max2 = (uint16_t)hold_Max_2;
  *Min2 = (uint16_t)hold_Min_2;
  return Valid;
}

/******************************************************************************************/
int Limit_HR_Change ( uint16_t HR_in, bool Valid)
{ // HR_in is expected to carry the latest valid HR value.
  // Limit_HR_Delta.vi
  static uint16_t prev_HRin = 0;
  static uint16_t prev_HRout = 0;
  static bool First_Call = true;
  uint16_t HR_out = 0;

  if ( ( ( abs(HR_in - prev_HRin) > MAX_DELTA_HR ) && !First_Call) || !Valid )
  {
    HR_out = prev_HRout;
  }
  else
  {
    HR_out = HR_in;
  }

  prev_HRin = HR_in;
  prev_HRout = HR_out;
  First_Call = false;
  return HR_out;
}

/*******************************************************************************************/
int Calculate_Offsets ( uint16_t Red_Offset, uint16_t IR_Offset, uint16_t *New_Red_Offset, uint16_t *New_IR_Offset,
                       uint16_t Max1, uint16_t Min1, uint16_t Max2, uint16_t Min2 )
{ // Update the offsets for both IR & Red
  // RunningCal.vi
  int Voff_tmp = 0;
  // LV equation = (Voff_target - (Max1-Min1)/2.0 ) * 0.2
  // Voff_tmp = (VOFF_TARGET - ((Max1 + Min1) / 2) ) * 2 / 5;
  // Approx LV Equation = (2.0 * Voff_target - (Max1-Min1)) / 5 -->> /5 reduced to /8
  Voff_tmp = (VOFF_TARGET << 1);
  Voff_tmp = Voff_tmp - (Max1 + Min1);
  Voff_tmp = Voff_tmp >> 3;

  // define Red Offset
  Voff_tmp = (int) (((VOFF_TARGET << 1) - (Max1 + Min1)) >> 3);
  // limit the change
  if ( Voff_tmp > MAX_OFFSET_CHANGE )
  {
    Voff_tmp = MAX_OFFSET_CHANGE;
  }
  if ( Voff_tmp < MIN_OFFSET_CHANGE )
  {
    Voff_tmp = MIN_OFFSET_CHANGE;
  }
  Voff_tmp =  Red_Offset + Voff_tmp;
  // Limit the magnitude
  if ( Voff_tmp > MAX_OFFSET )
  {
    Voff_tmp = MAX_OFFSET;
  }
  if ( Voff_tmp < MIN_OFFSET )
  {
    Voff_tmp = MIN_OFFSET;
  }
  *New_Red_Offset = (uint16_t) (Voff_tmp);

#ifdef UPDATE_OFFSETS
  Set_Offset_v2 ( *New_Red_Offset );          // Set Red Offset
#endif

  // define IR Offset
  // Voff_tmp = (VOFF_TARGET - (Max2 + Min2) / 2.0f ) * 0.2f;
  Voff_tmp = (int) (((VOFF_TARGET << 1) - (Max2 + Min2)) >> 3);
  if ( Voff_tmp > MAX_OFFSET_CHANGE)
  {
    Voff_tmp = MAX_OFFSET_CHANGE;
  }
  if ( Voff_tmp < MIN_OFFSET_CHANGE)
  {
    Voff_tmp = MIN_OFFSET_CHANGE;
  }
  Voff_tmp =  IR_Offset + Voff_tmp;
  // Limit the magnitude
  if ( Voff_tmp > MAX_OFFSET )
  {
    Voff_tmp = MAX_OFFSET;
  }
  if ( Voff_tmp < MIN_OFFSET )
  {
    Voff_tmp = MIN_OFFSET;
  }
  *New_IR_Offset = (uint16_t) (Voff_tmp);

#ifdef UPDATE_OFFSETS
  Set_Offset_v2 ( *New_IR_Offset );          // Set IR Offset
#endif

  return 0;
}

/*******************************************************************************************/
uint16_t Get_HR_v1 ( uint16_t Red, uint16_t iRed, uint16_t *Max1, uint16_t *Min1,
                    uint16_t *Max2, uint16_t *Min2, bool *hr_valid, bool prev_gTrack)
{ // In LV inputs are data & input_2
  uint16_t Vout, Vout2;
  static uint16_t HR_tmp = 0;
  static uint16_t HR_out = 0;

  Track_Run_Max_Min (Red, KUP, KDOWN, !prev_gTrack, &Vout, &Vout2);
  *hr_valid = HR3 ( Red, Vout, iRed, &HR_tmp, Max1, Min1, Max2, Min2 );


  HR_out = (uint16_t)Limit_HR_Change ( HR_tmp, hr_valid );

  return HR_out;
}

/************************************************************************************/
int rAverage( int K_avg, int Value, int Prev_Value, bool Init )
{
  if ( !Init)
  {
      return (K_avg * Value + (1000 - K_avg) * Prev_Value) / 1000;
  }
  else
  {
      return Value;
  }
}

/***************************************************************************************/
int Set_Offset ( float Value )
{// Code to control the Analog output offset
    // actually do it
    pulse_bias_v (Value);

    return 0;
}

/***************************************************************************************/
int Set_Offset_v2 ( uint16_t Value )
{// Code to control the Analog output offset
    static int DeltaBits = ADC_BITS - DAC_BITS;

    Value = (uint16_t)(Value << (DeltaBits));
    pulse_bias_v2 (Value);

    return 0;
}

/***************************************************************************************/
int pulse_ox_results(uint16_t *heart_rate, uint16_t *o2_saturation, uint16_t unfilterd_HR,
                     uint16_t Max1, uint16_t Min1, uint16_t Max2, uint16_t Min2, bool hr_valid,
                     uint16_t Red_Signal_Offset, uint16_t IR_Signal_offset)
{ // UpdateResChart.vi & "Obtain All Results" state in Test_Pulse_Ox.vi
  static uint16_t Prev_HR_out = 0;
  static bool Init_Filter = true;
  uint16_t avg_HR_Reading = 0;
  static uint16_t Prev_Max_Min_1 = 0;
  static uint16_t Prev_Max_Min_2 = 0;
  uint16_t avg_Max_Min_1, avg_Max_Min_2;
  static uint32_t invalid_tick = 0;


  if (hr_valid)
  {
    // valid reading; reset invalid_tick
    invalid_tick = 0;
    avg_HR_Reading = (uint16_t)rAverage(K_AVG_HR,  unfilterd_HR,  Prev_HR_out,  Init_Filter);
    Prev_HR_out = avg_HR_Reading;
    *heart_rate = Prev_HR_out;

    avg_Max_Min_1 = (uint16_t)rAverage(K_AVG_MAX_MIN,  (Max1 - Min1),  Prev_Max_Min_1,  Init_Filter);
    Prev_Max_Min_1 = avg_Max_Min_1;

    avg_Max_Min_2 = (uint16_t)rAverage(K_AVG_MAX_MIN,  (Max2 - Min2),  Prev_Max_Min_2,  Init_Filter);
    Prev_Max_Min_2 = avg_Max_Min_2;

    // NormRatio may need scaling
    NormRatio = (1.0f * avg_Max_Min_1 / avg_Max_Min_2) / ( 1.0f * Min1 / Min2);        // (IR_Signal_offset / Red_Signal_Offset);


    // Polynomial Approximation
    *o2_saturation = (uint16_t)((O2_Calc_Poly_Array[0] + O2_Calc_Poly_Array[1] * NormRatio + O2_Calc_Poly_Array[2] * NormRatio * NormRatio) / 1.0);
    Prev_O2_Saturation = *o2_saturation;

    if ( Init_Filter )
    {
        Init_Filter = false;
    }
  }
  else
  {
    // invalid so make decision based on invalid_tick count
    if (invalid_tick++ > HR_INVALID_TIME)
    {
        *heart_rate = 0;
        *o2_saturation = 0;
    }
    else
    {
        *heart_rate = Prev_HR_out;
        *o2_saturation = Prev_O2_Saturation;
    }
  }

  return 0;
}

/***************************************************************************************/
void pulse_adc_process_red (int value, bool prev_gTrack)
{
    //TODO:
    // handle processing of RED LED AD pulse
    static int Prev_Value = 0;
    static bool Init = true;


    if ( prev_gTrack)
    {
        RED_Reading =  (uint16_t)rAverage( RED_KAVG, value, Prev_Value, Init );
        Prev_Value = RED_Reading;
        Init = false;
    }
}

/***************************************************************************************/
void pulse_adc_process_ired (int value, bool prev_gTrack, uint16_t *heart_rate, uint16_t *o2_saturation)
{
    //TODO:
    static uint16_t Max1, Min1, Max2, Min2;
    bool hr_valid = false;
    uint16_t HR_out = 0;
    static int Prev_Value = 0;
    static bool Init = true;


    // handle processing of Infra RED LED AD pulse
    IR_Reading = (uint16_t)rAverage( IR_KAVG, value, Prev_Value, Init );
    Prev_Value = IR_Reading;
    Init = false;

    if ( prev_gTrack)
    {
        HR_out = Get_HR_v1 ( RED_Reading, IR_Reading, &Max1, &Min1, &Max2, &Min2, &hr_valid, prev_gTrack ) ;
//        Calculate_Offsets ( g_RED_Offset, g_IR_Offset, &g_RED_Offset, &g_IR_Offset, Max1, Min1, Max2, Min2 );
        pulse_ox_results(heart_rate, o2_saturation, HR_out, Max1, Min1, Max2, Min2, hr_valid, g_RED_Offset, g_IR_Offset);
        Vout1_Track = RED_Reading;
        Vout2_Track = IR_Reading;
#ifdef FAKE_PULSE_OX_HR
        *heart_rate = FAKE_PULSE_OX_HR;
#endif
#ifdef FAKE_PULSE_OX_O2
        *o2_saturation = FAKE_PULSE_OX_O2;
#endif
        // update this values
        pulse_ox_update (*heart_rate, *o2_saturation);
    }
}

/******************************************************************************************/
void pulse_ox_idle_enter (void)
{
    // TODO: add logic to low power mode
    // top main timer
    g_timer_2.p_api->stop(g_timer_2.p_ctrl);
    led_all_off ();                                                                           //Turn off all LEDs
    // blank out LCD
    display_str("   ");
    // clear out BLE reported data
    tx_mutex_get(&g_data_mutex, TX_WAIT_FOREVER);
    memset(&g_healthcare_data, 0, sizeof(g_healthcare_data));
    tx_mutex_put(&g_data_mutex);
}

/******************************************************************************************/
void pulse_ox_idle_exit (void)
{
    // start main timer to resume ADC processing
    g_timer_2.p_api->start(g_timer_2.p_ctrl);
    // Exit idle mode
    led_green (POWER_LED);
    led_red (STATUS_LED);
}
