/*
 ****************************************************************************************
 * DISCLAIMER
 ****************************************************************************************
 * This software and/or information (the "Material") is supplied by Renesas Electronics
 * Corporation. and is only intended for use with Renesas products. No other uses are authorized.
 * The Material is owned by Renesas Electronics Corporation and is protected under all applicable laws,
 * including copyright laws.
 * THIS MATERIAL IS PROVIDED "AS IS," AND RENESAS MAKES NO WARRANTIES REGARDING THIS MATERIAL,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
 * TO THE MAXIMUM EXTENT PERMITTED BY LAW, NEITHER RENESAS ELECTRONICS CORP. NOR ANY OF ITS
 * AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS MATERIAL, EVEN IF RENESAS OR ITS AFFILIATES
 * HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this Material
 * and to discontinue its availability
 *
 ****************************************************************************************
 * pulse_bias.c
 *
 *  Created on: Feb 25, 2016
 *      Author: alejandro
 ****************************************************************************************
 */

#include "hal_data.h"


/*
 * This section needs to be moved to its own file
 *
 */
void pulse_bias_init (void)
{
    const dac_instance_t *dac = &g_dac;
    dac_ctrl_t      *ctrl = dac->p_ctrl;
    dac_cfg_t const *cfg = dac->p_cfg;
    dac_api_t const *api = dac->p_api;

    ssp_err_t err = api->open(ctrl, cfg);

    if (err != SSP_SUCCESS)
    {
        // TODO:
        // handle error case
    }
}

void pulse_bias_start (void)
{
    const dac_instance_t *dac = &g_dac;
    dac_ctrl_t      *ctrl = dac->p_ctrl;
    dac_api_t const *api = dac->p_api;

    ssp_err_t err = api->start (ctrl);

    if (err != SSP_SUCCESS)
    {
        // TODO:
        // handle error case
    }
}

void pulse_bias_v2 (uint16_t volt)
{
    const dac_instance_t *dac = &g_dac;
    dac_ctrl_t      *ctrl = dac->p_ctrl;
    dac_api_t const *api = dac->p_api;

    dac_size_t count;

    count = volt;

    // NOT needed since write does starts the module if it has not
    // here just because it was provided in the example
    ssp_err_t err = api->start (ctrl);

    if (SSP_SUCCESS == err)
    {
        // here just to match the example from Renesas
        //count = 0xaa;
        // write the count value representing the voltage passed
        err = api->write (ctrl, count);
    }

    if (SSP_SUCCESS == err)
    {
        //
    }
}


void pulse_bias_v (float volt)
{
    const dac_instance_t *dac = &g_dac;
    dac_ctrl_t      *ctrl = dac->p_ctrl;
    dac_api_t const *api = dac->p_api;
    int ad_max = ((1 << 12) - 1); // 12 bit DAC
    float unit;
    dac_size_t count;

    volt *= 1000;    // assume max of three decimal points
    unit = volt / BSP_CFG_MCU_VCC_MV ;
    unit *= (float)ad_max;
    count = (dac_size_t)unit;

    // NOT needed since write does starts the module if it has not
    // here just because it was provided in the example
    ssp_err_t err = api->start (ctrl);

    if (SSP_SUCCESS == err)
    {
        // here just to match the example from Renesas
        //count = 0xaa;
        // write the count value representing the voltage passed
        err = api->write (ctrl, count);
    }

    if (SSP_SUCCESS == err)
    {
        //
    }
}

void pulse_bias_p (int percent)
{
    float volt;

    volt = ((float)percent *  BSP_CFG_MCU_VCC_MV)/100.0f; // volt without decimal point
    volt /= 1000;   // volt brought down to correct range

    pulse_bias_v (volt);
}
