/**
 ****************************************************************************************
 *
 * @file        prf_config.c
 *
 * @brief   Setting of Configuration Parameters for Profile
 *
 * Copyright (C) RivieraWaves 2009-2012
 *
 * Copyright(C) 2013-2015 Renesas Electronics Corporation
 *
 * This file is generated by Bluetooth Developer Studio plugin.
 *     BDS Version    : 1.0.2095.0
 *     Script Version : 1.0.2
 *
 ****************************************************************************************
 */

/**
 * INCLUDE FILES
 ****************************************************************************************
 */
#include "arch.h"
#include "rwke_api.h"

#include "prf_config.h"
#include "db_handle.h"
#include "rble_api.h"

/**
 * VARIABLE DECLARATIONS
 ****************************************************************************************
 */
 
 /* profile task ID */

#if (USE_LINK_LOSS_SERVICE)
/*********************************
 * Link Loss service             *
 *********************************/
/** Link Loss Service */
static const uint16_t lls_svc = RBLE_SVC_LINK_LOSS;

/** Link Loss Service alert level characteristic */
static const struct atts_char_desc lls_alert_lvl_char = ATTS_CHAR(RBLE_GATT_CHAR_PROP_RD|RBLE_GATT_CHAR_PROP_WR,
                                                                  LLS_HDL_ALERT_LVL_VAL,
                                                                  RBLE_CHAR_ALERT_LEVEL);
/** LLS alert level value */
uint8_t svc_lls_alert_lvl = 0;

#endif  /* #if (USE_LINK_LOSS_SERVICE) */

#if (USE_TX_POWER_SERVICE)
/*********************************
 * TX Power service              *
 *********************************/
/** TX Power Service */
static const uint16_t tps_svc = RBLE_SVC_TX_POWER;

/** TX Power Service TX Power level characteristic (can be notifiable if BR/EDR) */
static const struct atts_char_desc tps_txpw_lvl_char = ATTS_CHAR(RBLE_GATT_CHAR_PROP_RD,
                                                                 TPS_HDL_TXPW_LVL_VAL,
                                                                 RBLE_CHAR_TX_POWER_LEVEL);
/** TPS Tx Power level - signed */
int8_t svc_txpw_lvl = 0;

#endif  /* #if (USE_LINK_LOSS_SERVICE) */

#if (USE_IMMEDIATE_ALERT_SERVICE)
/*********************************
 * Immediate Alert service       *
 *********************************/
/** Immediate Alert Service */
static const uint16_t ias_svc = RBLE_SVC_IMMEDIATE_ALERT;

/** Immediate Alert Service alert level characteristic */
static const struct atts_char_desc ias_alert_lvl_char = ATTS_CHAR(RBLE_GATT_CHAR_PROP_WR_NO_RESP,
                                                           IAS_HDL_ALERT_LVL_VAL,
                                                           RBLE_CHAR_ALERT_LEVEL);
/** IAS alert level value */
uint8_t svc_ias_alert_lvl = 0;

#endif  /* #if (USE_IMMEDIATE_ALERT_SERVICE) */

#if (USE_DEV_INFO_SERVICE || USE_DEV_INFO_SERVICE_PNP)
/*********************************
 * Device Information service    *
 *********************************/
/** Device Information Service */
static const uint16_t dis_svc = RBLE_SVC_DEVICE_INFORMATION;

#if (USE_DEV_INFO_SERVICE)
/** System ID Characteristic */
static const struct atts_char_desc dis_sys_id_char = ATTS_CHAR(RBLE_GATT_CHAR_PROP_RD,
                                                         DIS_HDL_SYS_ID_VAL,
                                                         RBLE_CHAR_SYSTEM_ID);
/** System ID value (8octets) */
static const uint8_t dis_sys_id_desc[8] = { 0, 0, 0, 0, 0, 0, 0, 0 };

/** Model Number Characteristic */
static const struct atts_char_desc dis_model_nb_char = ATTS_CHAR(RBLE_GATT_CHAR_PROP_RD,
                                                          DIS_HDL_MODEL_NB_VAL,
                                                          RBLE_CHAR_MODEL_NUMBER_STRING);
/** Model Number String */
static const uint8_t dis_model_nb_desc[]    = "Renesas HC Demo";

/** Serial Number characteristic */
static const struct atts_char_desc dis_serial_nb_char = ATTS_CHAR(RBLE_GATT_CHAR_PROP_RD,
                                                           DIS_HDL_SERIAL_NB_VAL,
                                                           RBLE_CHAR_SERIAL_NUMBER_STRING);
/** Serial Number String */
static const uint8_t dis_serial_nb_desc[] = "1.0.0.0-LE";

/** Firmware Revision Characteristic */
static const struct atts_char_desc dis_fw_rev_char = ATTS_CHAR(RBLE_GATT_CHAR_PROP_RD,
                                                         DIS_HDL_FW_REV_VAL,
                                                         RBLE_CHAR_FW_REVISION_STRING);
/** Firmware Revision String */
static const uint8_t dis_fw_rev_desc[] = "1.0.0";

/** Hardware Revision Characteristic */
static const struct atts_char_desc dis_hw_rev_char = ATTS_CHAR(RBLE_GATT_CHAR_PROP_RD,
                                                         DIS_HDL_HW_REV_VAL,
                                                         RBLE_CHAR_HW_REVISION_STRING);
/** Hardware Revision String **/
static const uint8_t dis_hw_rev_desc[] = "1.0.0";

/** Software Revision Characteristic */
static const struct atts_char_desc dis_sw_rev_char = ATTS_CHAR(RBLE_GATT_CHAR_PROP_RD,
                                                         DIS_HDL_SW_REV_VAL,
                                                         RBLE_CHAR_SW_REVISION_STRING);
/** Software Revision String */
static const uint8_t dis_sw_rev_desc[] = "1.0.0";

/** Manufacturer Name Characteristic **/
static const struct atts_char_desc dis_manuf_name_char = ATTS_CHAR(RBLE_GATT_CHAR_PROP_RD,
                                                       DIS_HDL_MANUF_NAME_VAL,
                                                       RBLE_CHAR_MANUF_NAME_STRING);
/** Manufacturer Name String */
static const uint8_t dis_manuf_name_desc[] = "Renesas Electronics";

/** IEEE 11073-20601 Regulatory Certification Data List */
static const struct atts_char_desc dis_ieee_certif_char = ATTS_CHAR(RBLE_GATT_CHAR_PROP_RD,
                                                              DIS_HDL_IEEE_CERTIF_VAL,
                                                              RBLE_CHAR_IEEE_CERTIF);
/** IEEE 11073-20601 Regulatory Certification Data List Value (Min:6octets) */
static const uint8_t dis_ieee_certif_desc[] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };

#endif /* #if (USE_DEV_INFO_SERVICE) */

#if (USE_DEV_INFO_SERVICE_PNP)

#define PNP_ID(vendor_id_src, vendor_id, product_id, product_ver)   { (uint8_t)((vendor_id_src)),   \
                                        (uint8_t)((vendor_id)),     (uint8_t)((vendor_id) >> 8),    \
                                        (uint8_t)((product_id)),    (uint8_t)((product_id) >> 8),   \
                                        (uint8_t)((product_ver)),   (uint8_t)((product_ver) >> 8)}

#define VENDOR_ID_SRC   RBLE_SVC_SIG_ASSIGNED_ID
#define VENDOR_ID       0x0000u
#define PRODUCT_ID      0x0000u
#define PRODUCT_VER     0x0000u

/** PnP ID characteristic */
static const struct atts_char_desc dis_pnp_id_char = ATTS_CHAR(RBLE_GATT_CHAR_PROP_RD,
                                                        DIS_HDL_PNP_ID_VAL,
                                                        RBLE_CHAR_PNP_ID);

/** PnP ID Value */
static const uint8_t dis_pnp_id[] = PNP_ID(VENDOR_ID_SRC, VENDOR_ID, PRODUCT_ID, PRODUCT_VER);

#endif  /* #if (!USE_DEV_INFO_SERVICE_PNP) */
#endif /* #if (USE_DEV_INFO_SERVICE || USE_DEV_INFO_SERVICE_PNP) */

#if (USE_BATTERY_SERVICE)
/*********************************
 * Battery Service(Instance 1)   *
 *********************************/
/** Battery Service(Instance 1) **/
static const uint16_t bas_svc1 = RBLE_SVC_BATTERY_SERVICE;
/** Battery Level characteristic(Instance 1) **/
static const struct atts_char_desc bas_battery_lvl_char1 = ATTS_CHAR(RBLE_GATT_CHAR_PROP_RD | RBLE_GATT_CHAR_PROP_NTF,
                                                              BAS1_HDL_BATTERY_LVL_VAL,
                                                              RBLE_CHAR_BATTERY_LEVEL);

/** Battery Level characteristic(Instance 1) Presentation Format */
static const uint8_t bas1_char_presen[] = {
    0x00,           /* Format */
    0x00,           /* Exponent */
    0x00, 0x00,     /* Unit(UUID) */
    0x01,           /* Namespace */
    0x00, 0x00      /* Description */
};

#ifdef HID_MULTI_INSTANCE
/*********************************
 * Battery Service(Instance 2)   *
 *********************************/
/** Battery Service(Instance 2) **/
static const uint16_t bas_svc2 = RBLE_SVC_BATTERY_SERVICE;
/** Battery Level characteristic(Instance 2) **/
static const struct atts_char_desc bas_battery_lvl_char2 = ATTS_CHAR(RBLE_GATT_CHAR_PROP_RD | RBLE_GATT_CHAR_PROP_NTF,
                                                              BAS2_HDL_BATTERY_LVL_VAL,
                                                              RBLE_CHAR_BATTERY_LEVEL);

/** Battery Level characteristic(Instance 2) Presentation Format */
static const uint8_t bas2_char_presen[] = {
    0x00,           /* Format */
    0x00,           /* Exponent */
    0x00, 0x00,     /* Unit(UUID) */
    0x01,           /* Namespace */
    0x00, 0x00      /* Description */
};

#endif  /* #ifdef HID_MULTI_INSTANCE */

struct batt_service bas_inst[RBLE_BAS_INST_MAX] = {
    /* Instance 1 */
    {
        0x0000u,                        /* Battery Level permission settings notification of the characteristic values */
        { 0, RBLE_HGHD_INPUT_REPORT },  /* Report Reference descriptor values of property Battery Level */
        0                               /* Characteristic value Battery Level */
    },
    /* Instance 2 */
    {
        0x0000u,                        /* Battery Level permission settings notification of the characteristic values */
        { 0, RBLE_HGHD_INPUT_REPORT },  /* Report Reference descriptor values of property Battery Level */
        0                               /* Characteristic value Battery Level */
    }
};

#endif  /* #if (USE_BATTERY_SERVICE) */

#if (USE_SCAN_PARAMETER_SERVICE)
/*********************************
 * Scan Parameters Service       *
 *********************************/
/** Scan Parameters Service */
static const uint16_t scanparam_svc = RBLE_SVC_SCAN_PARAMETERS;

/** Scan Parameters Service Scan Interval Window characteristic */
static const struct atts_char_desc scans_intv_window_char = ATTS_CHAR(RBLE_GATT_CHAR_PROP_WR_NO_RESP,
                                                               SCANS_HDL_INTV_WINDOW_VAL,
                                                               RBLE_CHAR_SCAN_INTERVAL_WINDOW);
/** Scan Parameters Service Scan Refresh characteristic */
static const struct atts_char_desc scans_refresh_char = ATTS_CHAR(RBLE_GATT_CHAR_PROP_NTF,
                                                           SCANS_HDL_REFRESH_VAL,
                                                           RBLE_CHAR_SCAN_REFRESH);
/** Scan interval window characteristic variable */
struct svc_scans_intv_window scans_intv_window = { 0x0000u, 0x0000u };
/** Scan refresh characteristic value */
uint8_t scans_refresh_val = 0;
/** Scan refresh notification configuration */
uint16_t scans_refresh_ntf_en = 0x0000u;
#endif  /* #if (USE_SCAN_PARAMETER_SERVICE) */

#ifdef USE_SAMPLE_PROFILE
/*******************************
 * Sample Custom Service       *
 *******************************/
/* --------------------------------------------------------------------------------------------- */
/* Service(Service1) */
static const uint8_t service1_svc[RBLE_GATT_128BIT_UUID_OCTET] = RBLE_SVC_SAMPLE_CUSTOM_SVC_SERVICE1;

/* Characteristc(Service1:sv1_char1_ntf) */
static const struct atts_char128_desc sv1_char1_ntf_char = {
	RBLE_GATT_CHAR_PROP_NTF,
	{(uint8_t)(SCS_HDL_SERVICE1_SV1_CHAR1_NTF_VAL & 0xff),(uint8_t)((SCS_HDL_SERVICE1_SV1_CHAR1_NTF_VAL >> 8) & 0xff)},
	RBLE_CHAR_SCP_SV1_CHAR1_NTF};

uint8_t sv1_char1_ntf_char_val[RBLE_ATTM_MAX_VALUE] = {0};

struct atts_elmt_128 sv1_char1_ntf_char_val_elmt = {
	RBLE_CHAR_SCP_SV1_CHAR1_NTF,
	RBLE_GATT_128BIT_UUID_OCTET,
	&sv1_char1_ntf_char_val[0] };

uint16_t sv1_char1_ntf_en = 0x0000u;

/* Characteristc(Service1:sv1_char2_ntf) */
static const struct atts_char128_desc sv1_char2_ntf_char = {
	RBLE_GATT_CHAR_PROP_NTF,
	{(uint8_t)(SCS_HDL_SERVICE1_SV1_CHAR2_NTF_VAL & 0xff),(uint8_t)((SCS_HDL_SERVICE1_SV1_CHAR2_NTF_VAL >> 8) & 0xff)},
	RBLE_CHAR_SCP_SV1_CHAR2_NTF};

uint8_t sv1_char2_ntf_char_val[RBLE_ATTM_MAX_VALUE] = {0};

struct atts_elmt_128 sv1_char2_ntf_char_val_elmt = {
	RBLE_CHAR_SCP_SV1_CHAR2_NTF,
	RBLE_GATT_128BIT_UUID_OCTET,
	&sv1_char2_ntf_char_val[0] };

uint16_t sv1_char2_ntf_en = 0x0000u;

/* Characteristc(Service1:sv1_char3_w) */
static const struct atts_char128_desc sv1_char3_w_char = {
	RBLE_GATT_CHAR_PROP_WR,
	{(uint8_t)(SCS_HDL_SERVICE1_SV1_CHAR3_W_VAL & 0xff),(uint8_t)((SCS_HDL_SERVICE1_SV1_CHAR3_W_VAL >> 8) & 0xff)},
	RBLE_CHAR_SCP_SV1_CHAR3_W};

uint16_t sv1_char3_w_char_val = 0x0064u;;

struct atts_elmt_128 sv1_char3_w_char_val_elmt = {
	RBLE_CHAR_SCP_SV1_CHAR3_W,
	RBLE_GATT_128BIT_UUID_OCTET,
	&sv1_char3_w_char_val };

uint16_t sv1_char3_w_en = 0x0000u;

#endif /* #ifdef USE_SAMPLE_PROFILE */

/** Attribute Database */
const struct atts_desc atts_desc_list_prf[] =
{
    #if (USE_LINK_LOSS_SERVICE)
    /*********************************
     * Link Loss service             *
     *********************************/
    { RBLE_DECL_PRIMARY_SERVICE,
        sizeof(lls_svc),            sizeof(lls_svc),            TASK_ATTID(TASK_SVC, LLS_IDX_PRIM_SVC),         RBLE_GATT_PERM_RD,                      (void *)&lls_svc },
    /*  Link Loss Alert Level characteristic */
    { RBLE_DECL_CHARACTERISTIC,
        sizeof(lls_alert_lvl_char), sizeof(lls_alert_lvl_char), TASK_ATTID(TASK_SVC, LLS_IDX_ALERT_LVL_CHAR),   RBLE_GATT_PERM_RD,                      (void *)&lls_alert_lvl_char },
    /* Link Loss Alert Level Value */
    { RBLE_CHAR_ALERT_LEVEL,
        sizeof(svc_lls_alert_lvl),  sizeof(svc_lls_alert_lvl),  TASK_ATTID(TASK_SVC, LLS_IDX_ALERT_LVL_VAL),    (RBLE_GATT_PERM_RD|RBLE_GATT_PERM_WR),  (void *)&svc_lls_alert_lvl },
    #endif /* #if (USE_LINK_LOSS_SERVICE) */

    #if (USE_TX_POWER_SERVICE)
    /*********************************
     * TX Power service              *
     *********************************/
    /*  TX Power service */
    { RBLE_DECL_PRIMARY_SERVICE,
        sizeof(tps_svc),            sizeof(tps_svc),            TASK_ATTID(TASK_SVC, TPS_IDX_PRIM_SVC),         RBLE_GATT_PERM_RD,          (void *)&tps_svc },
    /*  TX Power TX Power Level characteristic */
    { RBLE_DECL_CHARACTERISTIC,
        sizeof(tps_txpw_lvl_char),  sizeof(tps_txpw_lvl_char),  TASK_ATTID(TASK_SVC, TPS_IDX_TXPW_LVL_CHAR),    RBLE_GATT_PERM_RD,          (void *)&tps_txpw_lvl_char },
    /* TX Power TX Power Level Value */
    { RBLE_CHAR_TX_POWER_LEVEL,
        sizeof(svc_txpw_lvl),       sizeof(svc_txpw_lvl),       TASK_ATTID(TASK_SVC, TPS_IDX_TXPW_LVL_VAL),     RBLE_GATT_PERM_RD,          (void *)&svc_txpw_lvl },
    #endif /* #if (USE_TX_POWER_SERVICE) */

    #if (USE_IMMEDIATE_ALERT_SERVICE)
    /*********************************
     * Immediate Alert service       *
     *********************************/
    { RBLE_DECL_PRIMARY_SERVICE,
        sizeof(ias_svc),            sizeof(ias_svc),            TASK_ATTID(TASK_SVC, IAS_IDX_PRIM_SVC),         RBLE_GATT_PERM_RD,          (void *)&ias_svc },
    /*  Immediate Alert Alert Level characteristic */
    { RBLE_DECL_CHARACTERISTIC,
        sizeof(ias_alert_lvl_char), sizeof(ias_alert_lvl_char), TASK_ATTID(TASK_SVC, IAS_IDX_ALERT_LVL_CHAR),   RBLE_GATT_PERM_RD,          (void *)&ias_alert_lvl_char },
    /* Immediate Alert Alert Level Value */
    { RBLE_CHAR_ALERT_LEVEL,
        sizeof(svc_ias_alert_lvl),  sizeof(svc_ias_alert_lvl),  TASK_ATTID(TASK_SVC, IAS_IDX_ALERT_LVL_VAL),    RBLE_GATT_PERM_WR,          (void *)&svc_ias_alert_lvl },
    #endif /* #if (USE_IMMEDIATE_ALERT_SERVICE) */

    #if (USE_DEV_INFO_SERVICE || USE_DEV_INFO_SERVICE_PNP)
    /*********************************
     * Device Information service    *
     *********************************/
    { RBLE_DECL_PRIMARY_SERVICE,
        sizeof(dis_svc),                sizeof(dis_svc),                TASK_ATTID(TASK_SVC, DIS_IDX_SVC),              RBLE_GATT_PERM_RD,      (void *)&dis_svc },
    #if (USE_DEV_INFO_SERVICE)
    /*  System ID characteristic definition*/
    { RBLE_DECL_CHARACTERISTIC,
        sizeof(dis_sys_id_char),        sizeof(dis_sys_id_char),        TASK_ATTID(TASK_SVC, DIS_IDX_SYS_ID_CHAR),      RBLE_GATT_PERM_RD,      (void *)&dis_sys_id_char },
    /* System ID Value */
    { RBLE_CHAR_SYSTEM_ID,
        sizeof(dis_sys_id_desc),        sizeof(dis_sys_id_desc),        TASK_ATTID(TASK_SVC, DIS_IDX_SYS_ID_VAL),       RBLE_GATT_PERM_RD,      (void *)&dis_sys_id_desc[0] },
    /*  Model Number characteristic definition*/
    { RBLE_DECL_CHARACTERISTIC,
        sizeof(dis_model_nb_char),      sizeof(dis_model_nb_char),      TASK_ATTID(TASK_SVC, DIS_IDX_MODEL_NB_CHAR),    RBLE_GATT_PERM_RD,      (void *)&dis_model_nb_char },
    /* Model Number  Value */
    { RBLE_CHAR_MODEL_NUMBER_STRING,
        sizeof(dis_model_nb_desc),      sizeof(dis_model_nb_desc),      TASK_ATTID(TASK_SVC, DIS_IDX_MODEL_NB_VAL),     RBLE_GATT_PERM_RD,      (void *)&dis_model_nb_desc[0] },
    /*  Serial Number characteristic definition*/
    { RBLE_DECL_CHARACTERISTIC,
        sizeof(dis_serial_nb_char),     sizeof(dis_serial_nb_char),     TASK_ATTID(TASK_SVC, DIS_IDX_SERIAL_NB_CHAR),   RBLE_GATT_PERM_RD,      (void *)&dis_serial_nb_char },
    /* Serial Number  Value */
    { RBLE_CHAR_SERIAL_NUMBER_STRING,
        sizeof(dis_serial_nb_desc),     sizeof(dis_serial_nb_desc),     TASK_ATTID(TASK_SVC, DIS_IDX_SERIAL_NB_VAL),    RBLE_GATT_PERM_RD,      (void *)&dis_serial_nb_desc[0] },
    /*  Firmware Revision characteristic definition*/
    { RBLE_DECL_CHARACTERISTIC,
        sizeof(dis_fw_rev_char),        sizeof(dis_fw_rev_char),        TASK_ATTID(TASK_SVC, DIS_IDX_FW_REV_CHAR),      RBLE_GATT_PERM_RD,      (void *)&dis_fw_rev_char },
    /* Firmware Revision Value */
    { RBLE_CHAR_FW_REVISION_STRING,
        sizeof(dis_fw_rev_desc),        sizeof(dis_fw_rev_desc),        TASK_ATTID(TASK_SVC, DIS_IDX_FW_REV_VAL),       RBLE_GATT_PERM_RD,      (void *)&dis_fw_rev_desc[0] },
    /*  Hardware Revision characteristic definition*/
    { RBLE_DECL_CHARACTERISTIC,
        sizeof(dis_hw_rev_char),        sizeof(dis_hw_rev_char),        TASK_ATTID(TASK_SVC, DIS_IDX_HW_REV_CHAR),      RBLE_GATT_PERM_RD,      (void *)&dis_hw_rev_char },
    /* Hardware Revision Value */
    { RBLE_CHAR_HW_REVISION_STRING,
        sizeof(dis_hw_rev_desc),        sizeof(dis_hw_rev_desc),        TASK_ATTID(TASK_SVC, DIS_IDX_HW_REV_VAL),       RBLE_GATT_PERM_RD,      (void *)&dis_hw_rev_desc[0] },
    /*  Software Revision characteristic definition*/
    { RBLE_DECL_CHARACTERISTIC,
        sizeof(dis_sw_rev_char),        sizeof(dis_sw_rev_char),        TASK_ATTID(TASK_SVC, DIS_IDX_SW_REV_CHAR),      RBLE_GATT_PERM_RD,      (void *)&dis_sw_rev_char },
    /* Software Revision Value */
    { RBLE_CHAR_SW_REVISION_STRING,
        sizeof(dis_sw_rev_desc),        sizeof(dis_sw_rev_desc),        TASK_ATTID(TASK_SVC, DIS_IDX_SW_REV_VAL),       RBLE_GATT_PERM_RD,      (void *)&dis_sw_rev_desc[0] },
    /*  Manufacturer Name characteristic definition*/
    { RBLE_DECL_CHARACTERISTIC,
        sizeof(dis_manuf_name_char),    sizeof(dis_manuf_name_char),    TASK_ATTID(TASK_SVC, DIS_IDX_MANUF_NAME_CHAR),  RBLE_GATT_PERM_RD,      (void *)&dis_manuf_name_char },
    /*  Manufacturer Name  Value */
    { RBLE_CHAR_MANUF_NAME_STRING,
        sizeof(dis_manuf_name_desc),    sizeof(dis_manuf_name_desc),    TASK_ATTID(TASK_SVC, DIS_IDX_MANUF_NAME_VAL),   RBLE_GATT_PERM_RD,      (void *)&dis_manuf_name_desc[0] },
    /*  IEEE Certifications List characteristic definition*/
    { RBLE_DECL_CHARACTERISTIC,
        sizeof(dis_ieee_certif_char),   sizeof(dis_ieee_certif_char),   TASK_ATTID(TASK_SVC, DIS_IDX_IEEE_CERTIF_CHAR), RBLE_GATT_PERM_RD,      (void *)&dis_ieee_certif_char },
    /* IEEE Certifications List Value */
    { RBLE_CHAR_IEEE_CERTIF,
        sizeof(dis_ieee_certif_desc),   sizeof(dis_ieee_certif_desc),   TASK_ATTID(TASK_SVC, DIS_IDX_IEEE_CERTIF_VAL),  RBLE_GATT_PERM_RD,      (void *)&dis_ieee_certif_desc[0] },
    #endif /* #if (USE_DEV_INFO_SERVICE) */
    #if (USE_DEV_INFO_SERVICE_PNP)
    /*  PnP ID characteristic definition*/
    { RBLE_DECL_CHARACTERISTIC,
        sizeof(dis_pnp_id_char),        sizeof(dis_pnp_id_char),        TASK_ATTID(TASK_SVC, DIS_IDX_PNP_ID_CHAR),      RBLE_GATT_PERM_RD,      (void *)&dis_pnp_id_char },
    /* PnP ID Value */
    { RBLE_CHAR_PNP_ID,
        sizeof(dis_pnp_id),             sizeof(dis_pnp_id),             TASK_ATTID(TASK_SVC, DIS_IDX_PNP_ID_VAL),       RBLE_GATT_PERM_RD,      (void *)&dis_pnp_id[0] },
    #endif /* #if (USE_DEV_INFO_SERVICE_PNP) */
    #endif /* #if (USE_DEV_INFO_SERVICE || USE_DEV_INFO_SERVICE_PNP) */

    #if (USE_BATTERY_SERVICE)
    /*********************************
     * Battery Service(Instance 1)   *
     *********************************/
    { RBLE_DECL_PRIMARY_SERVICE,
        sizeof(bas_svc1),                       sizeof(bas_svc1),                       TASK_ATTID(TASK_SVC, BAS1_IDX_SVC),                 RBLE_GATT_PERM_RD,          (void *)&bas_svc1 },
    /* Battery Level characteristic(Instance 1) */
    { RBLE_DECL_CHARACTERISTIC,
        sizeof(bas_battery_lvl_char1),          sizeof(bas_battery_lvl_char1),          TASK_ATTID(TASK_SVC, BAS1_IDX_BATTERY_LVL_CHAR),    RBLE_GATT_PERM_RD,          (void *)&bas_battery_lvl_char1 },
    /* Battery Level characteristic(Instance 1) Value */
    { RBLE_CHAR_BATTERY_LEVEL,
        sizeof(bas_inst[0].battery_lvl),        sizeof(bas_inst[0].battery_lvl),        TASK_ATTID(TASK_SVC, BAS1_IDX_BATTERY_LVL_VAL),     (RBLE_GATT_PERM_RD|RBLE_GATT_PERM_NI),  (void *)&bas_inst[0].battery_lvl },
    /* Battery Level characteristic(Instance 1) Notification Cfg Value */
    { RBLE_DESC_CLIENT_CHAR_CONF,
        sizeof(bas_inst[0].battery_lvl_ntf_en), sizeof(bas_inst[0].battery_lvl_ntf_en), TASK_ATTID(TASK_SVC, BAS1_IDX_BATTERY_LVL_CFG),     (RBLE_GATT_PERM_RD|RBLE_GATT_PERM_WR),  (void *)&bas_inst[0].battery_lvl_ntf_en },
    /* Battery Level characteristic(Instance 1) Presentation Format */
    { RBLE_DESC_CHAR_PRESENTATION_FMT,
        sizeof(bas1_char_presen),               sizeof(bas1_char_presen),               TASK_ATTID(TASK_SVC, BAS1_IDX_CHAR_PRESEN_FMT),     RBLE_GATT_PERM_RD,          (void *)&bas1_char_presen[0] },
    #ifdef HID_MULTI_INSTANCE
    /*********************************
     * Battery Service(Instance 2)   *
     *********************************/
    { RBLE_DECL_PRIMARY_SERVICE,
        sizeof(bas_svc2),                       sizeof(bas_svc2),                       TASK_ATTID(TASK_SVC, BAS2_IDX_SVC),                 RBLE_GATT_PERM_RD,          (void *)&bas_svc2 },
    /* Battery Level characteristic(Instance 2) */
    { RBLE_DECL_CHARACTERISTIC,
        sizeof(bas_battery_lvl_char2),          sizeof(bas_battery_lvl_char2),          TASK_ATTID(TASK_SVC, BAS2_IDX_BATTERY_LVL_CHAR),    RBLE_GATT_PERM_RD,          (void *)&bas_battery_lvl_char2 },
    /* Battery Level characteristic(Instance 2) Value */
    { RBLE_CHAR_BATTERY_LEVEL,
        sizeof(bas_inst[1].battery_lvl),        sizeof(bas_inst[1].battery_lvl),        TASK_ATTID(TASK_SVC, BAS2_IDX_BATTERY_LVL_VAL),     (RBLE_GATT_PERM_RD|RBLE_GATT_PERM_NI),  (void *)&bas_inst[1].battery_lvl },
    /* Battery Level characteristic(Instance 2) Notification Cfg Value */
    { RBLE_DESC_CLIENT_CHAR_CONF,
        sizeof(bas_inst[1].battery_lvl_ntf_en), sizeof(bas_inst[1].battery_lvl_ntf_en), TASK_ATTID(TASK_SVC, BAS2_IDX_BATTERY_LVL_CFG),     (RBLE_GATT_PERM_RD|RBLE_GATT_PERM_WR),  (void *)&bas_inst[1].battery_lvl_ntf_en },
    /* Battery Level characteristic(Instance 2) Presentation Format */
    { RBLE_DESC_CHAR_PRESENTATION_FMT,
        sizeof(bas2_char_presen),               sizeof(bas2_char_presen),               TASK_ATTID(TASK_SVC, BAS2_IDX_CHAR_PRESEN_FMT),     RBLE_GATT_PERM_RD,          (void *)&bas2_char_presen[0] },
    #endif /* #ifdef HID_MULTI_INSTANCE */
    #endif /* #if (USE_BATTERY_SERVICE) */

    #if (USE_SCAN_PARAMETER_SERVICE)
    /*********************************
     * Scan Parameters Service       *
     *********************************/
    { RBLE_DECL_PRIMARY_SERVICE,
        sizeof(scanparam_svc),              sizeof(scanparam_svc),          TASK_ATTID(TASK_SVC, SCANS_IDX_SVC),                RBLE_GATT_PERM_RD,              (void *)&scanparam_svc },
    /* Scan Interval Window characteristic */
    { RBLE_DECL_CHARACTERISTIC,
        sizeof(scans_intv_window_char),     sizeof(scans_intv_window_char), TASK_ATTID(TASK_SVC, SCANS_IDX_INTV_WINDOW_CHAR),   RBLE_GATT_PERM_RD,              (void *)&scans_intv_window_char },
    /* Scan Interval Window Value */
    { RBLE_CHAR_SCAN_INTERVAL_WINDOW,
        sizeof(scans_intv_window),          sizeof(scans_intv_window),      TASK_ATTID(TASK_SVC, SCANS_IDX_INTV_WINDOW_VAL),    RBLE_GATT_PERM_WR,              (void *)&scans_intv_window },
    /* Scan Refresh characteristic */
    { RBLE_DECL_CHARACTERISTIC,
        sizeof(scans_refresh_char),         sizeof(scans_refresh_char),     TASK_ATTID(TASK_SVC, SCANS_IDX_REFRESH_CHAR),       RBLE_GATT_PERM_RD,              (void *)&scans_refresh_char },
    /* Scan Refresh Value */
    { RBLE_CHAR_SCAN_REFRESH,
        sizeof(scans_refresh_val),          sizeof(scans_refresh_val),      TASK_ATTID(TASK_SVC, SCANS_IDX_REFRESH_VAL),        RBLE_GATT_PERM_NI,              (void *)&scans_refresh_val },
    /* Scan Refresh Notification Cfg Value */
    { RBLE_DESC_CLIENT_CHAR_CONF,
        sizeof(scans_refresh_ntf_en),       sizeof(scans_refresh_ntf_en),   TASK_ATTID(TASK_SVC, SCANS_IDX_REFRESH_CFG),        (RBLE_GATT_PERM_RD|RBLE_GATT_PERM_WR),  (void *)&scans_refresh_ntf_en },
    #endif /* #if (USE_SCAN_PARAMETER_SERVICE) */

    #ifdef USE_SAMPLE_PROFILE
    /*********************************
     * Sample Custom Service         *
     *********************************/
	/* --------------------------------------------------------------------------------------------- */
	/* Service */
	{ RBLE_DECL_PRIMARY_SERVICE,
		sizeof(service1_svc),	sizeof(service1_svc),	TASK_ATTID(TASK_RBLE, SCS_IDX_SVC_SERVICE1),	RBLE_GATT_PERM_RD,	(void *)&service1_svc },
    /* Characteristic: sv1_char1_ntf */
	{ RBLE_DECL_CHARACTERISTIC,
		sizeof(sv1_char1_ntf_char),	sizeof(sv1_char1_ntf_char),	TASK_ATTID(TASK_RBLE,SCS_IDX_SERVICE1_SV1_CHAR1_NTF_CHAR),	RBLE_GATT_PERM_RD,	(void *)&sv1_char1_ntf_char },
	{ DB_TYPE_128BIT_UUID,
		sizeof(sv1_char1_ntf_char_val),	sizeof(sv1_char1_ntf_char_val),	TASK_ATTID(TASK_RBLE,SCS_IDX_SERVICE1_SV1_CHAR1_NTF_VAL),	(RBLE_GATT_PERM_NI),	(void *)&sv1_char1_ntf_char_val_elmt },
	{ RBLE_DESC_CLIENT_CHAR_CONF,
		sizeof(sv1_char1_ntf_en),	sizeof(sv1_char1_ntf_en),	TASK_ATTID(TASK_RBLE,SCS_IDX_SERVICE1_SV1_CHAR1_NTF_CFG),	(RBLE_GATT_PERM_RD|RBLE_GATT_PERM_WR),	(void *)&sv1_char1_ntf_en },
    /* Characteristic: sv1_char2_ntf */
    { RBLE_DECL_CHARACTERISTIC,
        sizeof(sv1_char2_ntf_char),	sizeof(sv1_char2_ntf_char),	TASK_ATTID(TASK_RBLE,SCS_IDX_SERVICE1_SV1_CHAR2_NTF_CHAR),	RBLE_GATT_PERM_RD,	(void *)&sv1_char2_ntf_char },
    { DB_TYPE_128BIT_UUID,
        sizeof(sv1_char2_ntf_char_val),	sizeof(sv1_char2_ntf_char_val),	TASK_ATTID(TASK_RBLE,SCS_IDX_SERVICE1_SV1_CHAR2_NTF_VAL),	(RBLE_GATT_PERM_NI),	(void *)&sv1_char2_ntf_char_val_elmt },
    { RBLE_DESC_CLIENT_CHAR_CONF,
        sizeof(sv1_char2_ntf_en),	sizeof(sv1_char2_ntf_en),	TASK_ATTID(TASK_RBLE,SCS_IDX_SERVICE1_SV1_CHAR2_NTF_CFG),	(RBLE_GATT_PERM_RD|RBLE_GATT_PERM_WR),	(void *)&sv1_char2_ntf_en },

	/* Characteristic: sv1_char3_w */
	{ RBLE_DECL_CHARACTERISTIC,
		sizeof(sv1_char3_w_char),	sizeof(sv1_char3_w_char),	TASK_ATTID(TASK_RBLE,SCS_IDX_SERVICE1_SV1_CHAR3_W_CHAR),	RBLE_GATT_PERM_RD,	(void *)&sv1_char3_w_char },
	{ DB_TYPE_128BIT_UUID,
		sizeof(sv1_char3_w_char_val),	sizeof(sv1_char3_w_char_val),	TASK_ATTID(TASK_RBLE,SCS_IDX_SERVICE1_SV1_CHAR3_W_VAL),	(RBLE_GATT_PERM_RD|RBLE_GATT_PERM_WR),	(void *)&sv1_char3_w_char_val_elmt },
    #endif /* #ifdef USE_SAMPLE_PROFILE */
    /* Reserved */
    {0,0,0,0,0,0}
};

const uint16_t ATT_PRF_DB_SIZE = sizeof(atts_desc_list_prf);


